/*******************************************************


BITVISION VIDEO SYNTHESIZER
(C) 2010 DANIEL LARSEN
LZXINDUSTRIES.NET

********************************************************/

#include <avr/io.h>
#include <avr/interrupt.h>
#include <inttypes.h>
#include <math.h>
#include <avr/sleep.h>
#include <avr/pgmspace.h>
#include <stdlib.h>

#define NUM_PALETTES 16
#define NUM_MODROUTINGS 16
#define NUM_IMAGES 16
#define XMODE_MAX 2
#define YMODE_MAX 3
#define LINEMODE_MAX 3
#define FBUFFER_HEIGHT 32
#define FBUFFER_WIDTH 32
#define PALETTE_SIZE 16
#define STARTLINE 38
#define ENDLINE 230
#define BLACKCOLOR 0
#define PEAK_THRESH 24
#define PEAK_THRESH2 120
#define PEAK_DELAY 4
#define ENVFOLLOWER_OFFSET 9

#define DELAY1	{asm volatile("nop");}
#define DELAY2 	{asm volatile("nop");asm volatile("nop");}
#define DELAY4	{asm volatile("nop");asm volatile("nop");asm volatile("nop");asm volatile("nop");}
#define DELAY8	{asm volatile("nop");asm volatile("nop");asm volatile("nop");asm volatile("nop");asm volatile("nop");asm volatile("nop");asm volatile("nop");asm volatile("nop");}
#define DELAY16 {asm volatile("nop");asm volatile("nop");asm volatile("nop");asm volatile("nop");asm volatile("nop");asm volatile("nop");asm volatile("nop");asm volatile("nop");asm volatile("nop");asm volatile("nop");asm volatile("nop");asm volatile("nop");asm volatile("nop");asm volatile("nop");asm volatile("nop");asm volatile("nop");}

#define SYNC_ON 				{ PORTB |= _BV(PB2); }
#define SYNC_OFF 				{ PORTB &= ~_BV(PB2); }
#define BLACK_ON				{ PORTB |= _BV(PB1); }
#define BLACK_OFF 				{ PORTB &= ~_BV(PB1); }
#define SATURATION_LO 			{ PORTB |= _BV(PB0); }
#define SATURATION_HI 			{ PORTB &= ~_BV(PB0); }
#define ADC_SELECT_ENVFOLLOWER 	{ ADMUX = 0x20; }
#define ADC_SELECT_PARAM1	   	{ ADMUX = 0x21; }
#define ADC_SELECT_PARAM2	   	{ ADMUX = 0x22; }
#define ADC_START			   	{ PRR &= ~_BV(PRADC); ADCSRA |= (1 << ADSC);  ADCSRA |= (1 << ADEN); }

#define LED1_ON					{ PORTB |= _BV(PB4); }
#define LED1_OFF				{ PORTB &= ~_BV(PB4); }
#define LED2_ON					{ PORTB |= _BV(PB5); }
#define LED2_OFF				{ PORTB &= ~_BV(PB5); }


//GENERAL VAR
volatile uint8_t i = 0;
volatile uint8_t j = 0;
volatile uint8_t k = 0;

//SYNC TIMING
volatile uint8_t field = 1;
volatile uint16_t line = 0;
volatile uint8_t displayline = 0;

//COUNTERS		
volatile uint8_t frmCnt1=0;
volatile uint8_t frmCnt1Speed=30;
volatile uint8_t frmCnt2=0;
volatile uint8_t frmCnt2Speed=30;
volatile uint8_t lCntSpeed=2;
	
volatile uint8_t pkDelayCnt=0;

volatile uint8_t param[2]={0,0};	
volatile uint8_t button[7]={0,0,0,0,0,0,0};
volatile uint8_t btoggle[7]={0,0,0,0,0,0,0};

volatile uint8_t peakDetect=0; 	//PEAK STATE

volatile uint8_t frqCnt=0;		//FREQUENCY COUNTER
volatile uint8_t frqRange=0;		//FREQUENCY RANGE


volatile uint8_t envFollower[192];	//ENVELOPE FOLLOWER

// BUFFER/RENDERING
volatile uint8_t fpalette[PALETTE_SIZE];		
volatile uint8_t tpalette[PALETTE_SIZE];	
volatile uint8_t fbuffer[FBUFFER_HEIGHT][FBUFFER_WIDTH];
volatile uint8_t curImage=0;
volatile uint8_t curPalette=0;
volatile uint8_t curLineMode=0;
volatile uint8_t curActionMode=0;
volatile uint8_t curCntMode=0;
volatile uint8_t satMode=1;
volatile uint8_t xmode=0;
volatile uint8_t ymode=0;
volatile uint8_t *yptr;
volatile uint8_t envOffset=0;

volatile uint8_t *yptr2;


//READ ONLY STORAGE IN PROGRAM SPACE

volatile uint8_t modroutings[NUM_MODROUTINGS] PROGMEM = {
	0b00000000, 0b00000000, 0b00000000, 0b00000000, 0b00000000, 0b00000000, 0b00000000, 0b00000000, 0b00000000, 0b00000000, 0b00000000, 0b00000000, 0b00000000, 0b00000000, 0b00000000, 0b00000000};

volatile uint8_t palettes[NUM_PALETTES][PALETTE_SIZE] PROGMEM = {	// 16, 16 color palettes

	{0b00000000, 0b01100000, 0b10000000, 0b11000000, 0b00100000, 0b01100000, 0b10100000, 0b11100000, 0b00001000, 0b01001000, 0b10001000, 0b11001000, 0b00101111, 0b01101111, 0b10101000, 0b11101000},
	{0b10000000, 0b10000100, 0b10000010, 0b10000110, 0b10000001, 0b10000101, 0b10000011, 0b10000111, 0b10100000, 0b10100100, 0b10100010, 0b10100110, 0b10100001, 0b10100101, 0b10100011, 0b10100111},
	{0b10000000, 0b10000100, 0b10000010, 0b10000110, 0b10000001, 0b10000101, 0b10000011, 0b10000111, 0b10100000, 0b10100100, 0b10100010, 0b10100110, 0b10100001, 0b10100101, 0b10100011, 0b10100111},
	{0b10000000, 0b10000100, 0b10000010, 0b10000110, 0b10000001, 0b10000101, 0b10000011, 0b10000111, 0b10100000, 0b10100100, 0b10100010, 0b10100110, 0b10100001, 0b10100101, 0b10100011, 0b10100111},

	{0b10000000, 0b10000100, 0b10000010, 0b10000110, 0b10000001, 0b10000101, 0b10000011, 0b10000111, 0b10100000, 0b10100100, 0b10100010, 0b10100110, 0b10100001, 0b10100101, 0b10100011, 0b10100111},
	{0b10000000, 0b10000100, 0b10000010, 0b10000110, 0b10000001, 0b10000101, 0b10000011, 0b10000111, 0b10100000, 0b10100100, 0b10100010, 0b10100110, 0b10100001, 0b10100101, 0b10100011, 0b10100111},
	{0b10000000, 0b10000100, 0b10000010, 0b10000110, 0b10000001, 0b10000101, 0b10000011, 0b10000111, 0b10100000, 0b10100100, 0b10100010, 0b10100110, 0b10100001, 0b10100101, 0b10100011, 0b10100111},
	{0b10000000, 0b10000100, 0b10000010, 0b10000110, 0b10000001, 0b10000101, 0b10000011, 0b10000111, 0b10100000, 0b10100100, 0b10100010, 0b10100110, 0b10100001, 0b10100101, 0b10100011, 0b10100111},
	{0b10000000, 0b10000100, 0b10000010, 0b10000110, 0b10000001, 0b10000101, 0b10000011, 0b10000111, 0b10100000, 0b10100100, 0b10100010, 0b10100110, 0b10100001, 0b10100101, 0b10100011, 0b10100111},
	{0b10000000, 0b10000100, 0b10000010, 0b10000110, 0b10000001, 0b10000101, 0b10000011, 0b10000111, 0b10100000, 0b10100100, 0b10100010, 0b10100110, 0b10100001, 0b10100101, 0b10100011, 0b10100111},
	{0b10000000, 0b10000100, 0b10000010, 0b10000110, 0b10000001, 0b10000101, 0b10000011, 0b10000111, 0b10100000, 0b10100100, 0b10100010, 0b10100110, 0b10100001, 0b10100101, 0b10100011, 0b10100111},
	{0b10000000, 0b10000100, 0b10000010, 0b10000110, 0b10000001, 0b10000101, 0b10000011, 0b10000111, 0b10100000, 0b10100100, 0b10100010, 0b10100110, 0b10100001, 0b10100101, 0b10100011, 0b10100111},
	{0b10000000, 0b10000100, 0b10000010, 0b10000110, 0b10000001, 0b10000101, 0b10000011, 0b10000111, 0b10100000, 0b10100100, 0b10100010, 0b10100110, 0b10100001, 0b10100101, 0b10100011, 0b10100111},
	{0b10000000, 0b10000100, 0b10000010, 0b10000110, 0b10000001, 0b10000101, 0b10000011, 0b10000111, 0b10100000, 0b10100100, 0b10100010, 0b10100110, 0b10100001, 0b10100101, 0b10100011, 0b10100111},
	{0b10000000, 0b10000100, 0b10000010, 0b10000110, 0b10000001, 0b10000101, 0b10000011, 0b10000111, 0b10100000, 0b10100100, 0b10100010, 0b10100110, 0b10100001, 0b10100101, 0b10100011, 0b10100111},
	{0b10000000, 0b10000100, 0b10000010, 0b10000110, 0b10000001, 0b10000101, 0b10000011, 0b10000111, 0b10100000, 0b10100100, 0b10100010, 0b10100110, 0b10100001, 0b10100101, 0b10100011, 0b10100111},
};

volatile uint8_t images[NUM_IMAGES][FBUFFER_HEIGHT][(FBUFFER_WIDTH)] PROGMEM = {	// 24, 32x32, 16 values		
{{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001111,0b00001111,0b00001111,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001111,0b00001111,0b00000110,0b00001111,0b00001111,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001111,0b00000110,0b00000110,0b00000110,0b00001111,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00001001,0b00001001,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001001,0b00001001,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00001001,0b00001001,0b00001001,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00001001,0b00001001,0b00001001,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00001001,0b00001001,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00001001,0b00001001,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00001001,0b00001001,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00001001,0b00001001,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00001001,0b00001001,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001001,0b00001001,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00001001,0b00001001,0b00000000,0b00000000,0b00000000,0b00001001,0b00000000,0b00000000,0b00001001,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001001,0b00000000,0b00000000,0b00001001,0b00000000,0b00000000,0b00000000,0b00001001,0b00001001,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00001001,0b00001001,0b00000000,0b00000000,0b00000000,0b00001001,0b00000000,0b00000000,0b00001001,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001001,0b00000000,0b00000000,0b00001001,0b00000000,0b00000000,0b00000000,0b00001001,0b00001001,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00001001,0b00001001,0b00000000,0b00000000,0b00000000,0b00001001,0b00000000,0b00000000,0b00001001,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001001,0b00000000,0b00000000,0b00001001,0b00000000,0b00000000,0b00000000,0b00001001,0b00001001,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00001001,0b00001001,0b00000000,0b00000000,0b00000000,0b00001001,0b00001001,0b00001001,0b00001001,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001001,0b00001001,0b00001001,0b00001001,0b00000000,0b00000000,0b00000000,0b00001001,0b00001001,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00001001,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001001,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001001,0b00000000,0b00001001,0b00001001,0b00001001,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,}},

{{0b00000000,0b00000000,0b00000001,0b00000010,0b00000011,0b00000100,0b00000110,0b00000111,0b00001000,0b00001010,0b00001011,0b00001100,0b00001101,0b00001110,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001110,0b00001101,0b00001100,0b00001011,0b00001010,0b00001001,0b00000111,0b00000110,0b00000100,0b00000011,0b00000010,0b00000001,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000001,0b00000010,0b00000100,0b00000101,0b00000110,0b00001000,0b00001001,0b00001010,0b00001100,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,0b00001111,0b00001110,0b00001110,0b00001101,0b00001100,0b00001011,0b00001001,0b00001000,0b00000111,0b00000101,0b00000100,0b00000011,0b00000001,0b00000000,0b00000000,},
{0b00000001,0b00000000,0b00000000,0b00000000,0b00000010,0b00000011,0b00000100,0b00000110,0b00000111,0b00001000,0b00001010,0b00001011,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001110,0b00001110,0b00001101,0b00001100,0b00001011,0b00001010,0b00001000,0b00000111,0b00000110,0b00000100,0b00000011,0b00000010,0b00000001,0b00000000,0b00000000,},
{0b00000010,0b00000001,0b00000001,0b00000000,0b00000001,0b00000010,0b00000011,0b00000101,0b00000110,0b00000111,0b00001001,0b00001010,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001101,0b00001101,0b00001100,0b00001011,0b00001010,0b00001001,0b00001000,0b00000110,0b00000101,0b00000011,0b00000010,0b00000001,0b00000000,0b00000001,0b00000001,},
{0b00000011,0b00000011,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000011,0b00000101,0b00000110,0b00000111,0b00001001,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001100,0b00001011,0b00001011,0b00001010,0b00001001,0b00001000,0b00000110,0b00000101,0b00000100,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000010,},
{0b00000100,0b00000100,0b00000011,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000100,0b00000101,0b00000110,0b00000111,0b00001000,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001010,0b00001001,0b00001001,0b00001000,0b00000110,0b00000101,0b00000100,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000011,0b00000100,},
{0b00000110,0b00000101,0b00000100,0b00000011,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000100,0b00000101,0b00000110,0b00000111,0b00001000,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001000,0b00000111,0b00000110,0b00000101,0b00000100,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000011,0b00000100,0b00000101,},
{0b00000111,0b00000110,0b00000110,0b00000101,0b00000011,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000100,0b00000101,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001000,0b00000111,0b00000111,0b00000110,0b00000101,0b00000100,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000011,0b00000101,0b00000110,0b00000110,},
{0b00001000,0b00001000,0b00000111,0b00000110,0b00000101,0b00000100,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000011,0b00000100,0b00000101,0b00000110,0b00000110,0b00000111,0b00000110,0b00000110,0b00000101,0b00000100,0b00000011,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000100,0b00000101,0b00000110,0b00000111,0b00001000,},
{0b00001010,0b00001001,0b00001000,0b00000111,0b00000110,0b00000101,0b00000100,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000011,0b00000100,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000100,0b00000011,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000100,0b00000101,0b00000110,0b00000111,0b00001000,0b00001001,},
{0b00001011,0b00001010,0b00001010,0b00001001,0b00000111,0b00000110,0b00000101,0b00000011,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000100,0b00000011,0b00000011,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000011,0b00000101,0b00000110,0b00000111,0b00001001,0b00001010,0b00001010,},
{0b00001100,0b00001100,0b00001011,0b00001010,0b00001001,0b00000111,0b00000110,0b00000101,0b00000011,0b00000010,0b00000001,0b00000000,0b00000001,0b00000001,0b00000010,0b00000011,0b00000011,0b00000011,0b00000010,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000011,0b00000101,0b00000110,0b00000111,0b00001001,0b00001010,0b00001011,0b00001100,},
{0b00001101,0b00001101,0b00001100,0b00001011,0b00001010,0b00001000,0b00000111,0b00000110,0b00000100,0b00000011,0b00000010,0b00000001,0b00000000,0b00000000,0b00000001,0b00000010,0b00000010,0b00000010,0b00000001,0b00000001,0b00000000,0b00000000,0b00000010,0b00000011,0b00000100,0b00000110,0b00000111,0b00001000,0b00001010,0b00001011,0b00001100,0b00001101,},
{0b00001110,0b00001110,0b00001101,0b00001100,0b00001011,0b00001001,0b00001000,0b00000111,0b00000101,0b00000100,0b00000011,0b00000001,0b00000000,0b00000000,0b00000000,0b00000001,0b00000001,0b00000001,0b00000000,0b00000000,0b00000000,0b00000001,0b00000011,0b00000100,0b00000101,0b00000110,0b00001000,0b00001001,0b00001010,0b00001100,0b00001101,0b00001110,},
{0b00001111,0b00001110,0b00001101,0b00001100,0b00001011,0b00001010,0b00001001,0b00000111,0b00000110,0b00000101,0b00000011,0b00000010,0b00000001,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000001,0b00000010,0b00000011,0b00000100,0b00000110,0b00000111,0b00001001,0b00001010,0b00001011,0b00001100,0b00001101,0b00001110,},
{0b00001111,0b00001111,0b00001110,0b00001101,0b00001100,0b00001010,0b00001001,0b00001000,0b00000110,0b00000101,0b00000100,0b00000011,0b00000010,0b00000001,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000100,0b00000101,0b00000110,0b00001000,0b00001001,0b00001010,0b00001100,0b00001101,0b00001110,0b00001111,},
{0b00001111,0b00001111,0b00001110,0b00001101,0b00001100,0b00001011,0b00001001,0b00001000,0b00000111,0b00000101,0b00000100,0b00000011,0b00000010,0b00000001,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000001,0b00000010,0b00000011,0b00000100,0b00000101,0b00000110,0b00001000,0b00001001,0b00001011,0b00001100,0b00001101,0b00001110,0b00001111,},
{0b00001111,0b00001111,0b00001110,0b00001101,0b00001100,0b00001011,0b00001001,0b00001000,0b00000110,0b00000101,0b00000100,0b00000011,0b00000010,0b00000001,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000100,0b00000101,0b00000110,0b00001000,0b00001001,0b00001010,0b00001100,0b00001101,0b00001110,0b00001111,},
{0b00001111,0b00001110,0b00001101,0b00001100,0b00001011,0b00001010,0b00001001,0b00000111,0b00000110,0b00000101,0b00000011,0b00000010,0b00000001,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000001,0b00000010,0b00000011,0b00000101,0b00000110,0b00000111,0b00001001,0b00001010,0b00001011,0b00001100,0b00001101,0b00001110,},
{0b00001110,0b00001110,0b00001101,0b00001100,0b00001011,0b00001001,0b00001000,0b00000111,0b00000101,0b00000100,0b00000011,0b00000010,0b00000001,0b00000000,0b00000000,0b00000001,0b00000001,0b00000001,0b00000000,0b00000000,0b00000000,0b00000001,0b00000011,0b00000100,0b00000101,0b00000111,0b00001000,0b00001001,0b00001011,0b00001100,0b00001101,0b00001110,},
{0b00001101,0b00001101,0b00001100,0b00001011,0b00001010,0b00001001,0b00000111,0b00000110,0b00000100,0b00000011,0b00000010,0b00000001,0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000001,0b00000001,0b00000000,0b00000000,0b00000001,0b00000010,0b00000011,0b00000100,0b00000110,0b00000111,0b00001001,0b00001010,0b00001011,0b00001100,0b00001101,},
{0b00001100,0b00001100,0b00001011,0b00001010,0b00001001,0b00001000,0b00000110,0b00000101,0b00000100,0b00000010,0b00000001,0b00000000,0b00000000,0b00000001,0b00000010,0b00000010,0b00000011,0b00000010,0b00000010,0b00000001,0b00000001,0b00000000,0b00000001,0b00000010,0b00000011,0b00000101,0b00000110,0b00000111,0b00001001,0b00001010,0b00001011,0b00001100,},
{0b00001011,0b00001011,0b00001010,0b00001001,0b00001000,0b00000110,0b00000101,0b00000100,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000010,0b00000011,0b00000100,0b00000100,0b00000100,0b00000011,0b00000011,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000100,0b00000101,0b00000110,0b00001000,0b00001001,0b00001010,0b00001011,},
{0b00001010,0b00001001,0b00001000,0b00000111,0b00000110,0b00000101,0b00000100,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000101,0b00000101,0b00000100,0b00000011,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000100,0b00000101,0b00000110,0b00000111,0b00001000,0b00001001,},
{0b00001001,0b00001000,0b00000111,0b00000110,0b00000101,0b00000100,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000011,0b00000100,0b00000101,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000101,0b00000100,0b00000011,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000100,0b00000101,0b00000110,0b00000111,0b00001000,},
{0b00000111,0b00000111,0b00000110,0b00000101,0b00000100,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000011,0b00000101,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001000,0b00000111,0b00000111,0b00000110,0b00000101,0b00000100,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000011,0b00000101,0b00000110,0b00000111,},
{0b00000110,0b00000101,0b00000100,0b00000011,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000100,0b00000101,0b00000110,0b00000111,0b00001000,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001000,0b00000111,0b00000110,0b00000101,0b00000100,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000011,0b00000100,0b00000101,},
{0b00000100,0b00000100,0b00000011,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000011,0b00000101,0b00000110,0b00000111,0b00001000,0b00001001,0b00001010,0b00001010,0b00001011,0b00001010,0b00001010,0b00001001,0b00001001,0b00000111,0b00000110,0b00000101,0b00000100,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000011,0b00000100,},
{0b00000011,0b00000011,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000011,0b00000101,0b00000110,0b00000111,0b00001001,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001100,0b00001011,0b00001011,0b00001010,0b00001001,0b00001000,0b00000110,0b00000101,0b00000100,0b00000010,0b00000001,0b00000000,0b00000001,0b00000010,0b00000011,},
{0b00000010,0b00000001,0b00000001,0b00000000,0b00000001,0b00000010,0b00000011,0b00000101,0b00000110,0b00000111,0b00001001,0b00001010,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001101,0b00001100,0b00001100,0b00001011,0b00001010,0b00001001,0b00000111,0b00000110,0b00000101,0b00000011,0b00000010,0b00000001,0b00000000,0b00000001,0b00000001,},
{0b00000001,0b00000000,0b00000000,0b00000001,0b00000010,0b00000011,0b00000100,0b00000110,0b00000111,0b00001000,0b00001010,0b00001011,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001110,0b00001101,0b00001101,0b00001100,0b00001011,0b00001010,0b00001000,0b00000111,0b00000110,0b00000100,0b00000011,0b00000010,0b00000001,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000001,0b00000010,0b00000100,0b00000101,0b00000110,0b00001000,0b00001001,0b00001010,0b00001100,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,0b00001111,0b00001110,0b00001110,0b00001101,0b00001100,0b00001011,0b00001001,0b00001000,0b00000111,0b00000101,0b00000100,0b00000011,0b00000001,0b00000000,0b00000000,}},

{{0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,},
{0b00000000,0b00000100,0b00000100,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,},
{0b00000000,0b00000100,0b00000100,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,},
{0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000100,0b00000100,0b00000100,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00001010,0b00001010,0b00001010,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000100,0b00000100,0b00000100,},
{0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00001010,0b00001010,0b00000000,0b00000100,0b00000100,0b00000100,0b00000100,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00001010,0b00001010,0b00001010,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000100,0b00000100,0b00000100,},
{0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00001010,0b00001010,0b00000000,0b00000100,0b00000100,0b00000100,0b00000100,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00001010,0b00001010,0b00001010,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000100,0b00000100,0b00000100,},
{0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000100,0b00000100,0b00000100,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00001010,0b00001010,0b00001010,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000100,0b00000100,0b00000100,},
{0b00001110,0b00001110,0b00001110,0b00001110,0b00000100,0b00000100,0b00000100,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00001110,0b00001110,0b00001110,0b00001010,0b00001010,0b00001010,0b00001010,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00001110,0b00001110,0b00001110,0b00001110,0b00000100,0b00000100,0b00000100,0b00000100,0b00000000,0b00001010,0b00001010,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00001110,0b00001110,0b00001110,0b00001010,0b00001010,0b00001010,0b00001010,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00001110,0b00001110,0b00001110,0b00001110,0b00000100,0b00000100,0b00000100,0b00000100,0b00000000,0b00001010,0b00001010,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00001110,0b00001110,0b00000000,0b00000000,0b00000100,0b00001010,0b00001010,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00001110,0b00001110,0b00001110,0b00001110,0b00000100,0b00000100,0b00000100,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00001010,0b00001010,0b00001010,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00001110,0b00001110,0b00001010,0b00001010,0b00001010,0b00001010,0b00001110,0b00001110,0b00001110,0b00001110,},
{0b00000000,0b00000000,0b00001010,0b00001010,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000100,0b00000100,0b00000000,0b00001010,0b00000000,0b00000000,0b00001010,0b00000000,0b00001110,0b00001110,0b00001110,0b00001010,0b00001010,0b00001010,0b00001010,0b00001110,0b00001110,0b00001110,0b00001110,},
{0b00000000,0b00000000,0b00000000,0b00001010,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000100,0b00000100,0b00000000,0b00001010,0b00000000,0b00000000,0b00001010,0b00000000,0b00001110,0b00001110,0b00001110,0b00001010,0b00001010,0b00001010,0b00001010,0b00001110,0b00001110,0b00001110,0b00001110,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00001110,0b00001110,0b00001110,0b00001110,0b00001010,0b00001010,0b00001010,0b00001010,0b00001110,0b00001110,0b00001110,0b00000000,0b00001010,0b00000000,0b00000000,0b00001010,0b00000000,0b00000100,0b00000100,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001010,0b00000000,0b00000000,0b00000000,},
{0b00001110,0b00001110,0b00001110,0b00001110,0b00001010,0b00001010,0b00001010,0b00001010,0b00001110,0b00001110,0b00001110,0b00000000,0b00001010,0b00000000,0b00000000,0b00001010,0b00000000,0b00000100,0b00000100,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001010,0b00001010,0b00000000,0b00000000,},
{0b00001110,0b00001110,0b00001110,0b00001110,0b00001010,0b00001010,0b00001010,0b00001010,0b00001110,0b00001110,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001010,0b00001010,0b00001010,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000100,0b00000100,0b00000100,0b00001110,0b00001110,0b00001110,0b00001110,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00001010,0b00001010,0b00000100,0b00000000,0b00000000,0b00001110,0b00001110,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00001010,0b00001010,0b00000000,0b00000100,0b00000100,0b00000100,0b00000100,0b00001110,0b00001110,0b00001110,0b00001110,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00001010,0b00001010,0b00001010,0b00001010,0b00001110,0b00001110,0b00001110,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00001010,0b00001010,0b00000000,0b00000100,0b00000100,0b00000100,0b00000100,0b00001110,0b00001110,0b00001110,0b00001110,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00001010,0b00001010,0b00001010,0b00001010,0b00001110,0b00001110,0b00001110,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000100,0b00000100,0b00000100,0b00001110,0b00001110,0b00001110,0b00001110,},
{0b00000100,0b00000100,0b00000100,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00001010,0b00001010,0b00001010,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000100,0b00000100,0b00000100,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,},
{0b00000100,0b00000100,0b00000100,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00001010,0b00001010,0b00001010,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000100,0b00000100,0b00000100,0b00000100,0b00000000,0b00001010,0b00001010,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,},
{0b00000100,0b00000100,0b00000100,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00001010,0b00001010,0b00001010,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000100,0b00000100,0b00000100,0b00000100,0b00000000,0b00001010,0b00001010,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,},
{0b00000100,0b00000100,0b00000100,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00001010,0b00001010,0b00001010,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000100,0b00000100,0b00000100,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,},
{0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000100,0b00000100,0b00000000,},
{0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000100,0b00000100,0b00000000,},
{0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,}},

{{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,},
{0b00000000,0b00000000,0b00000001,0b00000001,0b00000010,0b00000010,0b00000011,0b00000011,0b00000100,0b00000100,0b00000101,0b00000101,0b00000110,0b00000110,0b00000111,0b00000111,0b00001000,0b00001000,0b00001001,0b00001001,0b00001010,0b00001010,0b00001011,0b00001011,0b00001100,0b00001100,0b00001101,0b00001101,0b00001110,0b00001110,0b00001111,0b00001111,}},

{{0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,},
{0b00000000,0b00000101,0b00000101,0b00000101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000101,0b00000101,0b00000101,0b00000000,},
{0b00000000,0b00000000,0b00000101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000101,0b00000000,0b00000000,},
{0b00000101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000101,},
{0b00000101,0b00000101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000111,0b00001010,0b00001010,0b00000000,0b00001010,0b00000000,0b00001010,0b00000000,0b00001010,0b00000000,0b00001010,0b00000000,0b00001010,0b00000000,0b00001010,0b00000000,0b00001010,0b00000111,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000101,0b00000101,},
{0b00000101,0b00000101,0b00000101,0b00000000,0b00000000,0b00000010,0b00000111,0b00001010,0b00001100,0b00001100,0b00000010,0b00000000,0b00000010,0b00000000,0b00000010,0b00000000,0b00000010,0b00000000,0b00000010,0b00000000,0b00000010,0b00000000,0b00000010,0b00001100,0b00001010,0b00000111,0b00000010,0b00000000,0b00000000,0b00000101,0b00000101,0b00000101,},
{0b00000101,0b00000101,0b00000000,0b00000000,0b00000010,0b00000111,0b00001010,0b00001100,0b00001111,0b00001111,0b00000010,0b00000000,0b00000010,0b00000000,0b00000010,0b00000000,0b00000010,0b00000000,0b00000010,0b00000000,0b00000010,0b00000000,0b00000010,0b00001111,0b00001100,0b00001010,0b00000111,0b00000010,0b00000000,0b00000000,0b00000101,0b00000101,},
{0b00000101,0b00000000,0b00000000,0b00000010,0b00000111,0b00001010,0b00001100,0b00001111,0b00001111,0b00000000,0b00000111,0b00000000,0b00000111,0b00000000,0b00000111,0b00000000,0b00000111,0b00000000,0b00000111,0b00000000,0b00000111,0b00000000,0b00000111,0b00000000,0b00001111,0b00001100,0b00001010,0b00000111,0b00000010,0b00000000,0b00000000,0b00000101,},
{0b00000000,0b00000000,0b00000010,0b00000111,0b00001010,0b00001100,0b00001111,0b00001111,0b00000000,0b00000000,0b00000111,0b00000000,0b00000111,0b00000000,0b00000111,0b00000000,0b00000111,0b00000000,0b00000111,0b00000000,0b00000111,0b00000000,0b00000111,0b00000000,0b00000000,0b00001111,0b00001100,0b00001010,0b00000111,0b00000010,0b00000000,0b00000000,},
{0b00000000,0b00000010,0b00000111,0b00001010,0b00001100,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00001010,0b00000000,0b00001010,0b00000000,0b00001010,0b00000000,0b00001010,0b00000000,0b00001010,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00001111,0b00001100,0b00001010,0b00000111,0b00000010,0b00000000,},
{0b00000010,0b00000111,0b00001010,0b00001100,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00001010,0b00000000,0b00001010,0b00000000,0b00001010,0b00000000,0b00001010,0b00000000,0b00001010,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001100,0b00001010,0b00000111,0b00000010,},
{0b00000111,0b00001010,0b00001100,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001100,0b00000000,0b00001100,0b00000000,0b00001100,0b00000000,0b00001100,0b00000000,0b00001100,0b00000000,0b00001100,0b00000000,0b00001100,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001100,0b00001010,0b00000111,},
{0b00001010,0b00001100,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001100,0b00001010,},
{0b00001100,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000010,0b00000010,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001100,},
{0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,},
{0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000010,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000101,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000101,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000010,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000010,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000101,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000101,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000010,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000010,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000101,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000101,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000010,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000010,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000101,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000101,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000010,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000010,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000101,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000101,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000010,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000010,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000101,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000101,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000010,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,},
{0b00001100,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000010,0b00000010,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00001100,},
{0b00001010,0b00001100,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00001100,0b00001010,},
{0b00000111,0b00001010,0b00001100,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00001100,0b00001010,0b00000111,},
{0b00000010,0b00000111,0b00001010,0b00001100,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00001100,0b00001010,0b00000111,0b00000010,},
{0b00000010,0b00000010,0b00000111,0b00001010,0b00001100,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00001100,0b00001010,0b00000111,0b00000010,0b00000010,},
{0b00000010,0b00000010,0b00000010,0b00000111,0b00001010,0b00001100,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00001100,0b00001010,0b00000111,0b00000010,0b00000010,0b00000010,}},

{{0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,},
{0b00001010,0b00001010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00001010,0b00000000,0b00000000,0b00001010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00001010,0b00000000,0b00000000,0b00001010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00001010,0b00001010,},
{0b00000000,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00001010,0b00001010,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00000000,},
{0b00000000,0b00000000,0b00000010,0b00000010,0b00000000,0b00000000,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000000,0b00000010,0b00000010,0b00000000,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000000,0b00000000,0b00000010,0b00000010,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000010,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000010,0b00000010,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000010,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000010,0b00000010,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00000010,0b00000010,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000111,0b00000111,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000111,0b00000111,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,},
{0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000010,0b00000010,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,},
{0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000010,0b00000010,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,},
{0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000010,0b00000010,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,},
{0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,},
{0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,},
{0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000010,0b00000010,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000010,0b00000010,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000010,0b00000010,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000010,0b00000010,0b00000010,0b00001010,0b00000111,0b00000010,0b00000010,0b00000111,0b00001010,0b00000010,0b00000010,0b00000010,0b00000010,0b00001010,0b00000111,0b00000010,0b00000010,0b00000111,0b00001010,0b00000010,0b00000010,0b00000010,0b00000010,0b00001010,0b00000111,0b00000010,0b00000010,0b00000111,0b00001010,0b00000010,0b00000010,0b00000010,}},

{{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00001010,0b00001010,0b00000000,0b00000000,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00000000,0b00000000,0b00001111,0b00001111,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00001010,0b00001010,0b00000000,0b00000000,0b00001010,0b00001010,0b00000000,0b00000000,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00000000,0b00000000,0b00001010,0b00001010,0b00000000,0b00000000,0b00001111,0b00001111,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00001010,0b00001010,0b00000000,0b00000000,0b00001010,0b00001010,0b00000000,0b00000000,0b00001010,0b00001010,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00001010,0b00001010,0b00000000,0b00000000,0b00001010,0b00001010,0b00000000,0b00000000,0b00001111,0b00001111,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00001010,0b00001010,0b00000000,0b00000000,0b00001010,0b00001010,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00001010,0b00001010,0b00000000,0b00000000,0b00001111,0b00001111,0b00000000,0b00000000,0b00001111,0b00001111,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00001010,0b00001010,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00001111,0b00001111,0b00000000,0b00000000,0b00001111,0b00001111,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00001111,0b00001111,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000101,0b00000101,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,}},

{{0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000111,0b00000111,0b00000111,0b00000111,0b00000010,0b00000010,0b00000010,0b00000010,0b00000111,0b00000111,0b00000111,0b00000111,0b00000010,0b00000010,0b00000010,0b00000010,0b00000111,0b00000111,0b00000111,0b00000111,0b00000010,0b00000010,0b00000010,0b00000010,0b00000111,0b00000111,0b00000111,0b00000111,0b00000010,0b00000010,0b00000010,0b00000010,},
{0b00000010,0b00000010,0b00000010,0b00000010,0b00000111,0b00000111,0b00000111,0b00000111,0b00000010,0b00000010,0b00000010,0b00000010,0b00000111,0b00000111,0b00000111,0b00000111,0b00000010,0b00000010,0b00000010,0b00000010,0b00000111,0b00000111,0b00000111,0b00000111,0b00000010,0b00000010,0b00000010,0b00000010,0b00000111,0b00000111,0b00000111,0b00000111,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,},
{0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00001100,0b00001100,0b00001100,0b00001100,0b00001100,0b00000000,0b00000000,0b00000000,0b00001100,0b00001100,0b00001100,0b00001100,0b00001100,0b00000000,0b00000000,0b00000000,0b00001100,0b00001100,0b00001100,0b00001100,0b00001100,0b00000000,0b00000000,0b00000000,0b00001100,0b00001100,0b00001100,0b00001100,0b00001100,0b00000000,0b00000000,0b00000000,},
{0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,},
{0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,},
{0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,},
{0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,},
{0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,},
{0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,},
{0b00000000,0b00001010,0b00001010,0b00000000,0b00000111,0b00001111,0b00001111,0b00000111,0b00000000,0b00001010,0b00001010,0b00000000,0b00000111,0b00001111,0b00001111,0b00000111,0b00000000,0b00001010,0b00001010,0b00000000,0b00000111,0b00001111,0b00001111,0b00000111,0b00000000,0b00001010,0b00001010,0b00000000,0b00000111,0b00001111,0b00001111,0b00000111,},
{0b00000000,0b00001111,0b00001111,0b00000000,0b00000111,0b00001010,0b00001010,0b00000111,0b00000000,0b00001111,0b00001111,0b00000000,0b00000111,0b00001010,0b00001010,0b00000111,0b00000000,0b00001111,0b00001111,0b00000000,0b00000111,0b00001010,0b00001010,0b00000111,0b00000000,0b00001111,0b00001111,0b00000000,0b00000111,0b00001010,0b00001010,0b00000111,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,},
{0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000111,0b00001111,0b00001111,0b00000111,0b00000000,0b00001010,0b00001010,0b00000000,0b00000111,0b00001111,0b00001111,0b00000111,0b00000000,0b00001010,0b00001010,0b00000000,0b00000111,0b00001111,0b00001111,0b00000111,0b00000000,0b00001010,0b00001010,0b00000000,0b00000111,0b00001111,0b00001111,0b00000111,0b00000000,0b00001010,0b00001010,0b00000000,},
{0b00000111,0b00001010,0b00001010,0b00000111,0b00000000,0b00001111,0b00001111,0b00000000,0b00000111,0b00001010,0b00001010,0b00000111,0b00000000,0b00001111,0b00001111,0b00000000,0b00000111,0b00001010,0b00001010,0b00000111,0b00000000,0b00001111,0b00001111,0b00000000,0b00000111,0b00001010,0b00001010,0b00000111,0b00000000,0b00001111,0b00001111,0b00000000,},
{0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,},
{0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,},
{0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,},
{0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,},
{0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,},
{0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,},
{0b00001100,0b00001100,0b00001100,0b00001100,0b00001100,0b00000000,0b00000000,0b00000000,0b00001100,0b00001100,0b00001100,0b00001100,0b00001100,0b00000000,0b00000000,0b00000000,0b00001100,0b00001100,0b00001100,0b00001100,0b00001100,0b00000000,0b00000000,0b00000000,0b00001100,0b00001100,0b00001100,0b00001100,0b00001100,0b00000000,0b00000000,0b00000000,},
{0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,},
{0b00000010,0b00000010,0b00000010,0b00000010,0b00000111,0b00000111,0b00000111,0b00000111,0b00000010,0b00000010,0b00000010,0b00000010,0b00000111,0b00000111,0b00000111,0b00000111,0b00000010,0b00000010,0b00000010,0b00000010,0b00000111,0b00000111,0b00000111,0b00000111,0b00000010,0b00000010,0b00000010,0b00000010,0b00000111,0b00000111,0b00000111,0b00000111,},
{0b00000111,0b00000111,0b00000111,0b00000111,0b00000010,0b00000010,0b00000010,0b00000010,0b00000111,0b00000111,0b00000111,0b00000111,0b00000010,0b00000010,0b00000010,0b00000010,0b00000111,0b00000111,0b00000111,0b00000111,0b00000010,0b00000010,0b00000010,0b00000010,0b00000111,0b00000111,0b00000111,0b00000111,0b00000010,0b00000010,0b00000010,0b00000010,},
{0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,}},

{{0b00000000,0b00000000,0b00001010,0b00000010,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00001010,0b00000010,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,},
{0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,},
{0b00000000,0b00000000,0b00001010,0b00000010,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00001010,0b00000010,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,},
{0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,},
{0b00000000,0b00000000,0b00001010,0b00000010,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00001010,0b00000010,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,},
{0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,},
{0b00000000,0b00000000,0b00001010,0b00000010,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00001010,0b00000010,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,},
{0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,}},

{{0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001011,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00001011,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001011,0b00000110,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000110,0b00001011,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001011,0b00000110,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000100,0b00000110,0b00001011,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,},
{0b00001110,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00000110,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000100,0b00000110,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001110,},
{0b00001110,0b00001011,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00001011,0b00001110,},
{0b00001110,0b00001011,0b00000110,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000110,0b00001011,0b00001110,},
{0b00001110,0b00001011,0b00000110,0b00000100,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000110,0b00001011,0b00001110,},
{0b00001110,0b00001011,0b00000110,0b00000100,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000110,0b00001011,0b00001110,},
{0b00001110,0b00001011,0b00000110,0b00000100,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000010,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000110,0b00001011,0b00001110,},
{0b00001110,0b00001011,0b00000110,0b00000100,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000010,0b00000100,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000100,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000110,0b00001011,0b00001110,},
{0b00001110,0b00001011,0b00000110,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000100,0b00000101,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000101,0b00000100,0b00000010,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000100,0b00000110,0b00001011,0b00001110,},
{0b00001110,0b00001011,0b00000110,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000100,0b00000101,0b00000110,0b00001000,0b00001000,0b00001000,0b00001000,0b00001000,0b00001000,0b00000110,0b00000101,0b00000100,0b00000010,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000100,0b00000110,0b00001011,0b00001110,},
{0b00001110,0b00001011,0b00000110,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000100,0b00000101,0b00000110,0b00001000,0b00001011,0b00001011,0b00001011,0b00001011,0b00001000,0b00000110,0b00000101,0b00000100,0b00000010,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000100,0b00000110,0b00001011,0b00001110,},
{0b00001110,0b00001011,0b00000110,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000100,0b00000101,0b00000110,0b00001000,0b00001011,0b00001110,0b00001110,0b00001011,0b00001000,0b00000110,0b00000101,0b00000100,0b00000010,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000100,0b00000110,0b00001011,0b00001110,},
{0b00001110,0b00001011,0b00000110,0b00000100,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000010,0b00000100,0b00000101,0b00000110,0b00001000,0b00001011,0b00001110,0b00001110,0b00001011,0b00001000,0b00000110,0b00000101,0b00000100,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000110,0b00001011,0b00001110,},
{0b00001110,0b00001011,0b00000110,0b00000100,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000010,0b00000100,0b00000101,0b00000110,0b00001000,0b00001011,0b00001011,0b00001011,0b00001011,0b00001000,0b00000110,0b00000101,0b00000100,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000110,0b00001011,0b00001110,},
{0b00001110,0b00001011,0b00000110,0b00000100,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000010,0b00000100,0b00000101,0b00000110,0b00001000,0b00001000,0b00001000,0b00001000,0b00001000,0b00001000,0b00000110,0b00000101,0b00000100,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000110,0b00001011,0b00001110,},
{0b00001110,0b00001011,0b00000110,0b00000100,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000010,0b00000100,0b00000101,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000101,0b00000100,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000110,0b00001011,0b00001110,},
{0b00001110,0b00001011,0b00000110,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000100,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000100,0b00000010,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000100,0b00000110,0b00001011,0b00001110,},
{0b00001110,0b00001011,0b00000110,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000010,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000100,0b00000110,0b00001011,0b00001110,},
{0b00001110,0b00001011,0b00000110,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000100,0b00000110,0b00001011,0b00001110,},
{0b00001110,0b00001011,0b00000110,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000100,0b00000110,0b00001011,0b00001110,},
{0b00001110,0b00001011,0b00000110,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000110,0b00001011,0b00001110,},
{0b00001110,0b00001011,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000100,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00001011,0b00001110,},
{0b00001110,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00000110,0b00000100,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000110,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001110,},
{0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001011,0b00000110,0b00000100,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000010,0b00000010,0b00000010,0b00000010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000100,0b00000110,0b00001011,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001011,0b00000110,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000100,0b00000110,0b00001011,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001011,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00001011,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001011,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,}},

{{0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001001,0b00001001,0b00001001,0b00001001,0b00000000,0b00000000,0b00000000,0b00000000,0b00001001,0b00001001,0b00001001,0b00001001,0b00000000,0b00000000,0b00000000,0b00000000,0b00001001,0b00001001,0b00001001,0b00001001,0b00000000,0b00000000,0b00000000,0b00000000,0b00001001,0b00001001,0b00001001,0b00001001,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,},
{0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00001110,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00001110,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,},
{0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,},
{0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,},
{0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,},
{0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,},
{0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,},
{0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,0b00001110,0b00001001,0b00000011,0b00000000,},
{0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,},
{0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,},
{0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,},
{0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00001110,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00001110,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001001,0b00001001,0b00001001,0b00001001,0b00000000,0b00000000,0b00000000,0b00000000,0b00001001,0b00001001,0b00001001,0b00001001,0b00000000,0b00000000,0b00000000,0b00000000,0b00001001,0b00001001,0b00001001,0b00001001,0b00000000,0b00000000,0b00000000,0b00000000,0b00001001,0b00001001,0b00001001,0b00001001,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,0b00000000,0b00000000,0b00000000,0b00000000,0b00001110,0b00001110,0b00001110,0b00001110,}},

{{0b00000000,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000000,0b00000000,0b00001101,0b00001101,0b00001101,0b00001101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001101,0b00001101,0b00001101,0b00001101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000000,},
{0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00001101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001101,0b00000000,0b00000000,0b00000000,},
{0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,},
{0b00000000,0b00001101,0b00001101,0b00001101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001101,0b00001101,0b00001101,0b00000000,},
{0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000011,0b00000000,0b00001111,0b00001111,0b00001111,0b00000011,0b00000011,0b00000011,0b00000011,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000011,0b00000011,0b00000011,0b00000011,0b00001111,0b00001111,0b00001111,0b00000000,0b00000011,0b00000000,0b00000000,0b00000000,},
{0b00001101,0b00001101,0b00001101,0b00001101,0b00000000,0b00001111,0b00001111,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001111,0b00001111,0b00000000,0b00001101,0b00001101,0b00001101,0b00001101,},
{0b00000000,0b00000111,0b00000111,0b00000111,0b00000000,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00000000,0b00000111,0b00000111,0b00000111,0b00000000,},
{0b00000000,0b00000000,0b00000011,0b00000011,0b00000000,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00000000,0b00000011,0b00000011,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00001101,0b00000000,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00000000,0b00001101,0b00000000,0b00000000,0b00000000,},
{0b00001101,0b00001101,0b00001101,0b00001101,0b00000000,0b00001111,0b00001111,0b00001111,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00001111,0b00001111,0b00001111,0b00000000,0b00001111,0b00001101,0b00001101,0b00001101,},
{0b00000000,0b00000011,0b00000011,0b00000011,0b00000000,0b00001101,0b00001101,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001101,0b00001101,0b00000000,0b00000011,0b00000011,0b00000011,0b00000000,},
{0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000011,0b00001101,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00001101,0b00001101,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001101,0b00000011,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00001101,0b00000000,0b00000011,0b00001101,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001101,0b00000011,0b00000000,0b00001101,0b00000000,0b00000000,0b00000000,},
{0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00001101,0b00001101,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001101,0b00001101,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,},
{0b00000000,0b00001101,0b00001101,0b00001101,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00001101,0b00001101,0b00001101,0b00000000,},
{0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00001111,0b00001111,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000011,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000011,0b00000000,0b00000000,0b00000000,},
{0b00001101,0b00001101,0b00001101,0b00001101,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00001101,0b00001101,0b00001101,0b00001101,},
{0b00000000,0b00000111,0b00000111,0b00000111,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000111,0b00000111,0b00000111,0b00000000,},
{0b00000000,0b00000000,0b00000011,0b00000011,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000011,0b00000011,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00001101,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00001101,0b00000000,0b00000000,0b00000000,},
{0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,},
{0b00000000,0b00000011,0b00000011,0b00000011,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001101,0b00001101,0b00001101,0b00001101,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000011,0b00000011,0b00000011,0b00000000,},
{0b00000000,0b00000000,0b00001101,0b00001101,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001101,0b00000011,0b00000011,0b00001101,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00001101,0b00001101,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000111,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001101,0b00001101,0b00001101,0b00001101,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000111,0b00000000,0b00000000,0b00000000,},
{0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,},
{0b00000000,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00000000,},
{0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000111,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000000,},
{0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,}},

{{0b00000110,0b00000110,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000110,0b00000110,},
{0b00000000,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000000,},
{0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00001101,0b00001101,0b00001101,0b00001101,0b00000000,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00000000,0b00001101,0b00001101,0b00001101,0b00000000,0b00000000,0b00001101,0b00001101,0b00001101,0b00000000,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00000000,0b00001101,0b00001101,0b00001101,0b00001101,},
{0b00001101,0b00001101,0b00001101,0b00001101,0b00000000,0b00001111,0b00000000,0b00000110,0b00000110,0b00000000,0b00001111,0b00000000,0b00001101,0b00001101,0b00001101,0b00000000,0b00000000,0b00001101,0b00001101,0b00001101,0b00000000,0b00001111,0b00000000,0b00000110,0b00000110,0b00000000,0b00001111,0b00000000,0b00001101,0b00001101,0b00001101,0b00001101,},
{0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00001111,0b00000000,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000000,0b00001111,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,},
{0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00001111,0b00000000,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000000,0b00001111,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,},
{0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00001111,0b00001111,0b00001111,0b00000000,0b00000011,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00001111,0b00000011,0b00000000,0b00001111,0b00001111,0b00001111,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,},
{0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000011,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00001111,0b00000011,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,},
{0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000011,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00000011,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000110,0b00001101,0b00001101,0b00001101,0b00001101,0b00000110,0b00000000,0b00000011,0b00001111,0b00001111,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000011,0b00000000,0b00000110,0b00001101,0b00001101,0b00001101,0b00001101,0b00000110,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000011,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00000011,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000011,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00001111,0b00001111,0b00000011,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000011,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00000011,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000011,0b00001111,0b00001111,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000011,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000110,0b00001101,0b00001101,0b00001101,0b00001101,0b00000110,0b00000000,0b00000011,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00000011,0b00000000,0b00000110,0b00001101,0b00001101,0b00001101,0b00001101,0b00000110,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000011,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00001111,0b00001111,0b00000011,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,},
{0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000011,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00000011,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,},
{0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00001111,0b00001111,0b00001111,0b00000000,0b00000011,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000011,0b00000000,0b00001111,0b00001111,0b00001111,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,},
{0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00001111,0b00000000,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000000,0b00001111,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,},
{0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00001111,0b00000000,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000000,0b00001111,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,},
{0b00001101,0b00001101,0b00001101,0b00001101,0b00000000,0b00001111,0b00000000,0b00000110,0b00000110,0b00000000,0b00001111,0b00000000,0b00001101,0b00001101,0b00001101,0b00000000,0b00000000,0b00001101,0b00001101,0b00001101,0b00000000,0b00001111,0b00000000,0b00000110,0b00000110,0b00000000,0b00001111,0b00000000,0b00001101,0b00001101,0b00001101,0b00001101,},
{0b00001101,0b00001101,0b00001101,0b00001101,0b00000000,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00000000,0b00001101,0b00001101,0b00001101,0b00000000,0b00000000,0b00001101,0b00001101,0b00001101,0b00000000,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00000000,0b00001101,0b00001101,0b00001101,0b00001101,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,},
{0b00000000,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000000,},
{0b00000110,0b00000110,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000011,0b00000000,0b00000110,0b00000110,}},

{{0b00001001,0b00000000,0b00001101,0b00001101,0b00001101,0b00001001,0b00001001,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00001001,0b00001001,0b00001101,0b00001101,0b00001101,0b00000000,0b00001001,},
{0b00000000,0b00000000,0b00001101,0b00001101,0b00001001,0b00001001,0b00000101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000101,0b00001001,0b00001001,0b00001101,0b00001101,0b00000000,0b00000000,},
{0b00001101,0b00001101,0b00001101,0b00001001,0b00001001,0b00000101,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000101,0b00001001,0b00001001,0b00001101,0b00001101,0b00001101,},
{0b00001101,0b00001101,0b00001001,0b00001001,0b00000101,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000101,0b00001001,0b00001001,0b00001101,0b00001101,},
{0b00001101,0b00001001,0b00001001,0b00000101,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000101,0b00001001,0b00001001,0b00001101,},
{0b00001101,0b00001001,0b00000101,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000101,0b00001001,0b00001101,},
{0b00001101,0b00001001,0b00000101,0b00000000,0b00001111,0b00001111,0b00001101,0b00001101,0b00001101,0b00001001,0b00001001,0b00001101,0b00001101,0b00001101,0b00001111,0b00001111,0b00001111,0b00001111,0b00001101,0b00001101,0b00001101,0b00001001,0b00001001,0b00001101,0b00001101,0b00001101,0b00001111,0b00001111,0b00000000,0b00000101,0b00001001,0b00001101,},
{0b00001101,0b00001001,0b00000101,0b00000000,0b00001111,0b00001111,0b00001101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00001101,0b00001111,0b00001111,0b00001111,0b00001111,0b00001101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00001101,0b00001111,0b00001111,0b00000000,0b00000101,0b00001001,0b00001101,},
{0b00001101,0b00001001,0b00000101,0b00000000,0b00001111,0b00001111,0b00001101,0b00000101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000101,0b00001101,0b00001111,0b00001111,0b00001111,0b00001111,0b00001101,0b00000101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000101,0b00001101,0b00001111,0b00001111,0b00000000,0b00000101,0b00001001,0b00001101,},
{0b00001101,0b00001001,0b00000101,0b00000000,0b00001111,0b00001111,0b00001001,0b00000101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000101,0b00001001,0b00001111,0b00001111,0b00001111,0b00001111,0b00001001,0b00000101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000101,0b00001001,0b00001111,0b00001111,0b00000000,0b00000101,0b00001001,0b00001101,},
{0b00001101,0b00001001,0b00000101,0b00000000,0b00001111,0b00001111,0b00001001,0b00000101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000101,0b00001001,0b00001111,0b00001111,0b00001111,0b00001111,0b00001001,0b00000101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000101,0b00001001,0b00001111,0b00001111,0b00000000,0b00000101,0b00001001,0b00001101,},
{0b00001101,0b00001001,0b00001001,0b00000101,0b00000000,0b00001111,0b00001101,0b00000101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000101,0b00001101,0b00001111,0b00001111,0b00001111,0b00001111,0b00001101,0b00000101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000101,0b00001101,0b00001111,0b00000000,0b00000101,0b00001001,0b00001001,0b00001101,},
{0b00001101,0b00001101,0b00001001,0b00001001,0b00000101,0b00000000,0b00001101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00001101,0b00001111,0b00001111,0b00001111,0b00001111,0b00001101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00001101,0b00000000,0b00000101,0b00001001,0b00001001,0b00001101,0b00001101,},
{0b00000000,0b00000000,0b00001001,0b00001001,0b00000101,0b00000000,0b00001101,0b00001101,0b00001101,0b00001001,0b00001001,0b00001101,0b00001101,0b00001101,0b00001111,0b00001111,0b00001111,0b00001111,0b00001101,0b00001101,0b00001101,0b00001001,0b00001001,0b00001101,0b00001101,0b00001101,0b00000000,0b00000101,0b00001001,0b00001001,0b00000000,0b00000000,},
{0b00001101,0b00001101,0b00001001,0b00001001,0b00000101,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000101,0b00001001,0b00001001,0b00001101,0b00001101,},
{0b00001101,0b00001001,0b00001001,0b00000101,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000101,0b00001001,0b00001001,0b00001101,},
{0b00001101,0b00001001,0b00000101,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001101,0b00001001,0b00000000,0b00001101,0b00000000,0b00001001,0b00001101,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000101,0b00001001,0b00001101,},
{0b00001101,0b00001001,0b00000101,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001001,0b00000101,0b00000000,0b00001101,0b00000000,0b00000101,0b00001001,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000101,0b00001001,0b00001101,},
{0b00001101,0b00001001,0b00000101,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000101,0b00000000,0b00000000,0b00001101,0b00000000,0b00000000,0b00000101,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000101,0b00001001,0b00001101,},
{0b00001101,0b00001001,0b00000101,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00001101,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000101,0b00001001,0b00001101,},
{0b00001101,0b00001001,0b00001001,0b00000101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000101,0b00001001,0b00001001,0b00001101,},
{0b00001101,0b00001101,0b00001001,0b00001001,0b00000101,0b00000101,0b00000101,0b00000101,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000101,0b00000101,0b00000101,0b00000101,0b00001001,0b00001001,0b00001101,0b00001101,},
{0b00001101,0b00001101,0b00001101,0b00001001,0b00001001,0b00001001,0b00001001,0b00000101,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000101,0b00001001,0b00001001,0b00001001,0b00001001,0b00001101,0b00001101,0b00001101,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001001,0b00001001,0b00001001,0b00000101,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000101,0b00001001,0b00001001,0b00001001,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00001101,0b00001001,0b00001001,0b00001101,0b00001101,0b00001001,0b00001001,0b00000101,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000101,0b00001001,0b00001001,0b00001101,0b00001101,0b00001001,0b00001001,0b00001101,},
{0b00001101,0b00001001,0b00001001,0b00001101,0b00001101,0b00001001,0b00001001,0b00000101,0b00000000,0b00001111,0b00000000,0b00001111,0b00000000,0b00001111,0b00000000,0b00001111,0b00000000,0b00001111,0b00000000,0b00001111,0b00000000,0b00001111,0b00001111,0b00000000,0b00000101,0b00001001,0b00001001,0b00001101,0b00001101,0b00001001,0b00001001,0b00001101,},
{0b00001101,0b00001001,0b00001001,0b00001101,0b00001101,0b00001001,0b00001001,0b00000101,0b00000000,0b00001111,0b00000000,0b00001111,0b00000000,0b00001111,0b00000000,0b00001111,0b00000000,0b00001111,0b00000000,0b00001111,0b00000000,0b00001111,0b00001111,0b00000000,0b00000101,0b00001001,0b00001001,0b00001101,0b00001101,0b00001001,0b00001001,0b00001101,},
{0b00001101,0b00001001,0b00001001,0b00001101,0b00001101,0b00001001,0b00001001,0b00000101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000101,0b00001001,0b00001001,0b00001101,0b00001101,0b00001001,0b00001001,0b00001101,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001101,0b00001001,0b00001001,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00000101,0b00001001,0b00001001,0b00001101,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00001001,0b00001001,0b00000000,0b00001101,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001001,0b00001101,0b00000000,0b00001001,0b00001001,0b00000000,},
{0b00000000,0b00001001,0b00001001,0b00000000,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001001,0b00001001,0b00000101,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000101,0b00001001,0b00001001,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00000000,0b00001001,0b00001001,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001001,0b00001001,0b00001001,0b00000101,0b00000000,0b00000000,0b00000000,0b00000000,0b00000101,0b00001001,0b00001001,0b00001001,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00001101,0b00000000,0b00000000,0b00000000,0b00000000,}},

{{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001010,0b00001010,0b00001010,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00001111,0b00001111,0b00001010,0b00000110,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001111,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001010,0b00001111,0b00000000,0b00000000,0b00000000,0b00000110,0b00001010,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00001111,0b00001111,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001111,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00001111,0b00001111,0b00001010,0b00000000,0b00000000,0b00000000,0b00001010,0b00001111,0b00001010,0b00001111,0b00000000,0b00001111,0b00000000,0b00000000,0b00001010,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00000000,0b00001111,0b00001010,0b00001010,0b00000000,0b00000000,0b00001010,0b00001111,0b00001010,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00001010,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00000000,0b00001111,0b00001111,0b00001010,0b00001010,0b00000000,0b00001010,0b00001111,0b00001010,0b00000000,0b00001111,0b00001111,0b00000000,0b00000000,0b00001010,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001010,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00001010,0b00000000,0b00001010,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001010,0b00001010,0b00000000,0b00001010,0b00000110,0b00001010,0b00000000,0b00001010,0b00001010,0b00000000,0b00001010,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001010,0b00000000,0b00001010,0b00001010,0b00001010,0b00000000,0b00001010,0b00001010,0b00000000,0b00000000,0b00001010,0b00001010,0b00001111,0b00001111,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00001010,0b00001111,0b00001111,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001010,0b00000000,0b00000000,0b00000000,0b00001010,0b00001111,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00001111,0b00000000,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001010,0b00001010,0b00000000,0b00000000,0b00000000,0b00001010,0b00001010,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001010,0b00001010,0b00000000,0b00000110,0b00000110,0b00000110,0b00000000,0b00001010,0b00001010,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001010,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00001010,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001010,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00001010,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001010,0b00000000,0b00000110,0b00000110,0b00000110,0b00000110,0b00000110,0b00000000,0b00001010,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001010,0b00001010,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00001010,0b00001010,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001010,0b00001010,0b00001010,0b00000000,0b00001010,0b00001010,0b00001010,0b00000000,0b00001010,0b00001010,0b00001010,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001010,0b00000000,0b00001010,0b00001111,0b00001010,0b00000000,0b00001010,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001010,0b00000000,0b00001010,0b00001111,0b00001010,0b00000000,0b00001010,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001010,0b00001010,0b00001010,0b00001010,0b00000000,0b00001010,0b00001111,0b00001010,0b00000000,0b00001010,0b00001010,0b00001010,0b00001010,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001111,0b00001010,0b00000000,0b00000000,0b00000000,0b00000000,0b00001010,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,},
{0b00000110,0b00000110,0b00001010,0b00001010,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001010,0b00000110,0b00000110,0b00000110,0b00000110,0b00001010,0b00001111,0b00001010,0b00000110,0b00000110,0b00000110,0b00000110,0b00001010,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00001010,0b00001010,0b00000110,0b00000110,}},
{{0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000001,0b00000111,0b00000111,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,},
{0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,},
{0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,},
{0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00001111,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,},
{0b00001111,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,},
{0b00001111,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00001111,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00000000,0b00000111,0b00000111,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000111,0b00000000,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000000,0b00000111,0b00000000,0b00000000,},
{0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000111,0b00000111,0b00000000,},
{0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,},
{0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000111,0b00000000,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,},
{0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00000111,0b00000111,0b00000111,0b00001111,0b00001111,0b00001111,0b00000111,0b00000111,0b00000111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00001111,0b00000111,0b00001111,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000001,0b00000111,0b00000111,0b00000000,0b00000000,0b00001111,0b00000111,0b00001111,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000001,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00000111,0b00001111,0b00000000,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000111,0b00000111,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00000111,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000000,0b00000111,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00000000,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000000,0b00000111,0b00000000,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000111,0b00000111,0b00000000,},
{0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00001111,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,0b00000000,0b00000000,0b00000000,0b00000111,0b00000111,}},

};		



ISR(TIMER1_COMPA_vect) 
{
	PORTD = 0; SATURATION_LO; // PREPARE FOR COLORBURST
	if (line==263){
		line=1;
    } else {
		line++;
	} 

	if((line>(ENDLINE+23)) && line <(ENDLINE+27)){ 
        SYNC_OFF;DELAY16;DELAY16;DELAY16;DELAY16;
        SYNC_ON;DELAY16;							
        SYNC_ON;DELAY16;DELAY16;					
        SYNC_ON;DELAY4;
	} else {
        SYNC_ON;DELAY16;DELAY16;DELAY16;DELAY16;
        SYNC_OFF;DELAY16;							
        BLACK_OFF;DELAY16;DELAY16;					
        BLACK_ON;DELAY4;
	}	

	if(satMode){SATURATION_HI;}
	displayline=1;
}

void incrementXMode(void){
	xmode++;
	if(xmode>XMODE_MAX){ xmode=0; }
}

void incrementLineMode(void){
	curLineMode++;
	if(curLineMode>LINEMODE_MAX){ curLineMode=0; }
}

void incrementYMode(void){
	ymode++;
	if(ymode>YMODE_MAX){ ymode=0; }
}



int invertHue(int q){
	if((q&32)==32) { q-=32; } else { q+=32; }
	return q;
}

int invertValue(int q){
	if(q>=192){	q-=192; } 
	else if(q>=128) { q-=64; }
	else if(q>=64) { q+=64; }
	else { q+=192; }
	return q;
}

int randomColor(int q){
	q=(rand()&255);
	return q;
}

int randomHue(int q){
	q=q-(q&15);
	q+=((rand())&15);
	if(((rand())&1)){q=invertHue(q);}
	return q;
}

int randomValue(int q){
	int p=(q&63);
	q=((rand()&3)<<6)+p;
	return q;
}

int incrementHue(int q){
	if((q&15)==15){ q-=15; q=invertHue(q); }
	else { q++; } 
	return q;	
}

int incrementValue(int q){
	if(q>=192){	q-=192; }
	else { q+=64; }
	return q;	
}

int decrementHue(int q){
	if((q&15)==0){ q+=15; q=invertHue(q); }
	else { q--; } 
	return q;	
}

int decrementValue(int q){
	if(((q>>6)&3)==0){	q+=192; }
	else { q-=64; }
	return q;	
}

void setValue(int h){ // 0,1,2,3 max
	int q;
	for(k=0;k<PALETTE_SIZE;k++){
		q=fpalette[k];
		q = ((q&192)^q); //SET BRIGHTNESS TO 0
		q+= (h&3)*64;
		fpalette[k]=q;
	}
}


void allPalette(int cmode){ 
	for(k=0;k<PALETTE_SIZE;k++){
		switch(cmode){
			case 0: fpalette[k]=incrementHue(fpalette[k]); break;
			case 1: fpalette[k]=incrementValue(fpalette[k]); break;
			case 2: fpalette[k]=randomColor(fpalette[k]); break;
			case 3: fpalette[k]=randomHue(fpalette[k]); break;
			case 4: fpalette[k]=randomValue(fpalette[k]); break;
			case 5: fpalette[k]=invertHue(fpalette[k]);break;
		}
	}
	return;
}

void shiftPalette(int l){
	int q;
	for(q=0;q<l;q++){
		for(k=0;k<(PALETTE_SIZE-1);k++){ tpalette[k]=fpalette[k+1]; }
		tpalette[(PALETTE_SIZE-1)]=fpalette[0];
		for(k=0;k<PALETTE_SIZE;k++){ fpalette[k]=tpalette[k]; }		
	}
	return;
}


void randomPalette(int cmode){

	int r=(rand())&15;

	switch(cmode){
		case 0: fpalette[r]=incrementHue(fpalette[r]); break;
		case 1: fpalette[r]=incrementValue(fpalette[r]); break;
		case 2: fpalette[r]=randomColor(fpalette[r]); break;
		case 3: fpalette[r]=randomHue(fpalette[r]); break;
		case 4: fpalette[r]=randomValue(fpalette[r]); break;
		case 5: fpalette[r]=invertHue(fpalette[r]); break;
	}
	
	return;
}

void loadPalette(int t){
	for(i=0;i<PALETTE_SIZE;i++){
		fpalette[i]=pgm_read_byte(&(palettes[t][i]));
		tpalette[i]=fpalette[i];
	}
}
void incrementPalette(void){
	curPalette++;
	if(curPalette>=NUM_PALETTES){curPalette=0;}
	loadPalette(curPalette);
}
void incrementAction(void){
	curActionMode++;
	if(curActionMode>=4){curActionMode=0;}
}

void incrementCntAction(void){
	curCntMode++;
	if(curCntMode>=13){curCntMode=0;}
	
}

void lineUpdate(int i, int p){
	switch(curLineMode){
	case 0: //NOTHING
		tpalette[0]=fpalette[0];
		tpalette[1]=fpalette[1];
		tpalette[2]=fpalette[2];
		tpalette[3]=fpalette[3];
		tpalette[4]=fpalette[4];
		tpalette[5]=fpalette[5];
		tpalette[6]=fpalette[6];
		tpalette[7]=fpalette[7];
		tpalette[8]=fpalette[8];
		tpalette[9]=fpalette[9];
		tpalette[10]=fpalette[10];
		tpalette[11]=fpalette[11];
		tpalette[12]=fpalette[12];
		tpalette[13]=fpalette[13];
		tpalette[14]=fpalette[14];
		tpalette[15]=fpalette[15];
		break;
	case 1:	//PALETTE INDEXES ABOVE ENVELOPE AMPLITUDE = BLACK
		if(0<=p){ tpalette[0]=fpalette[0]; } else {	tpalette[0]=0; }		
		if(1<=p){ tpalette[1]=fpalette[1]; } else {	tpalette[1]=0; }		
		if(2<=p){ tpalette[2]=fpalette[2]; } else {	tpalette[2]=0; }		
		if(3<=p){ tpalette[3]=fpalette[3]; } else {	tpalette[3]=0; }		
		if(4<=p){ tpalette[4]=fpalette[4]; } else {	tpalette[4]=0; }		
		if(5<=p){ tpalette[5]=fpalette[5]; } else {	tpalette[5]=0; }		
		if(6<=p){ tpalette[6]=fpalette[6]; } else {	tpalette[6]=0; }		
		if(7<=p){ tpalette[7]=fpalette[7]; } else {	tpalette[7]=0; }		
		if(8<=p){ tpalette[8]=fpalette[8]; } else {	tpalette[8]=0; }		
		if(9<=p){ tpalette[9]=fpalette[9]; } else {	tpalette[9]=0; }		
		if(10<=p){ tpalette[10]=fpalette[10]; } else {	tpalette[10]=0; }		
		if(11<=p){ tpalette[11]=fpalette[11]; } else {	tpalette[11]=0; }		
		if(12<=p){ tpalette[12]=fpalette[12]; } else {	tpalette[12]=0; }		
		if(13<=p){ tpalette[13]=fpalette[13]; } else {	tpalette[13]=0; }		
		if(14<=p){ tpalette[14]=fpalette[14]; } else {	tpalette[14]=0; }		
		if(15<=p){ tpalette[15]=fpalette[15]; } else {	tpalette[15]=0; }	
		break;
	case 2: //PALETTE INDEXES BELOW ENVELOPE AMPLITUDE = BLACK
		if(0>=p){ tpalette[0]=fpalette[0]; } else {	tpalette[0]=0; }		
		if(1>=p){ tpalette[1]=fpalette[1]; } else {	tpalette[1]=0; }		
		if(2>=p){ tpalette[2]=fpalette[2]; } else {	tpalette[2]=0; }		
		if(3>=p){ tpalette[3]=fpalette[3]; } else {	tpalette[3]=0; }		
		if(4>=p){ tpalette[4]=fpalette[4]; } else {	tpalette[4]=0; }		
		if(5>=p){ tpalette[5]=fpalette[5]; } else {	tpalette[5]=0; }		
		if(6>=p){ tpalette[6]=fpalette[6]; } else {	tpalette[6]=0; }		
		if(7>=p){ tpalette[7]=fpalette[7]; } else {	tpalette[7]=0; }		
		if(8>=p){ tpalette[8]=fpalette[8]; } else {	tpalette[8]=0; }		
		if(9>=p){ tpalette[9]=fpalette[9]; } else {	tpalette[9]=0; }		
		if(10>=p){ tpalette[10]=fpalette[10]; } else {	tpalette[10]=0; }		
		if(11>=p){ tpalette[11]=fpalette[11]; } else {	tpalette[11]=0; }		
		if(12>=p){ tpalette[12]=fpalette[12]; } else {	tpalette[12]=0; }		
		if(13>=p){ tpalette[13]=fpalette[13]; } else {	tpalette[13]=0; }		
		if(14>=p){ tpalette[14]=fpalette[14]; } else {	tpalette[14]=0; }		
		if(15>=p){ tpalette[15]=fpalette[15]; } else {	tpalette[15]=0; }	
		break;
	case 3: p=frqRange;
		if(0>=p){ tpalette[0]=fpalette[0]; } else {	tpalette[0]=0; }		
		if(1>=p){ tpalette[1]=fpalette[1]; } else {	tpalette[1]=0; }		
		if(2>=p){ tpalette[2]=fpalette[2]; } else {	tpalette[2]=0; }		
		if(3>=p){ tpalette[3]=fpalette[3]; } else {	tpalette[3]=0; }		
		if(4>=p){ tpalette[4]=fpalette[4]; } else {	tpalette[4]=0; }		
		if(5>=p){ tpalette[5]=fpalette[5]; } else {	tpalette[5]=0; }		
		if(6>=p){ tpalette[6]=fpalette[6]; } else {	tpalette[6]=0; }		
		if(7>=p){ tpalette[7]=fpalette[7]; } else {	tpalette[7]=0; }		
		if(8>=p){ tpalette[8]=fpalette[8]; } else {	tpalette[8]=0; }		
		if(9>=p){ tpalette[9]=fpalette[9]; } else {	tpalette[9]=0; }		
		if(10>=p){ tpalette[10]=fpalette[10]; } else {	tpalette[10]=0; }		
		if(11>=p){ tpalette[11]=fpalette[11]; } else {	tpalette[11]=0; }		
		if(12>=p){ tpalette[12]=fpalette[12]; } else {	tpalette[12]=0; }		
		if(13>=p){ tpalette[13]=fpalette[13]; } else {	tpalette[13]=0; }		
		if(14>=p){ tpalette[14]=fpalette[14]; } else {	tpalette[14]=0; }		
		if(15>=p){ tpalette[15]=fpalette[15]; } else {	tpalette[15]=0; }	
		break;
	}

}


void loadFrameBuffer(int imageLoad){
	
	for(i=0;i<FBUFFER_HEIGHT;i++){	

		lineUpdate(i, ((envFollower[i]-7)+(envOffset-15))); //CHANGETHIS
		yptr=images[imageLoad][i];
		yptr2=fbuffer[i];
		yptr2[0]=tpalette[(pgm_read_byte(&(yptr[0])))];
		yptr2[1]=tpalette[(pgm_read_byte(&(yptr[1])))];
		yptr2[2]=tpalette[(pgm_read_byte(&(yptr[2])))];
		yptr2[3]=tpalette[(pgm_read_byte(&(yptr[3])))];
		yptr2[4]=tpalette[(pgm_read_byte(&(yptr[4])))];
		yptr2[5]=tpalette[(pgm_read_byte(&(yptr[5])))];
		yptr2[6]=tpalette[(pgm_read_byte(&(yptr[6])))];
		yptr2[7]=tpalette[(pgm_read_byte(&(yptr[7])))];
		yptr2[8]=tpalette[(pgm_read_byte(&(yptr[8])))];
		yptr2[9]=tpalette[(pgm_read_byte(&(yptr[9])))];
		yptr2[10]=tpalette[(pgm_read_byte(&(yptr[10])))];
		yptr2[11]=tpalette[(pgm_read_byte(&(yptr[11])))];
		yptr2[12]=tpalette[(pgm_read_byte(&(yptr[12])))];
		yptr2[13]=tpalette[(pgm_read_byte(&(yptr[13])))];
		yptr2[14]=tpalette[(pgm_read_byte(&(yptr[14])))];
		yptr2[15]=tpalette[(pgm_read_byte(&(yptr[15])))];
		yptr2[16]=tpalette[(pgm_read_byte(&(yptr[16])))];
		yptr2[17]=tpalette[(pgm_read_byte(&(yptr[17])))];
		yptr2[18]=tpalette[(pgm_read_byte(&(yptr[18])))];
		yptr2[19]=tpalette[(pgm_read_byte(&(yptr[19])))];
		yptr2[20]=tpalette[(pgm_read_byte(&(yptr[20])))];
		yptr2[21]=tpalette[(pgm_read_byte(&(yptr[21])))];
		yptr2[22]=tpalette[(pgm_read_byte(&(yptr[22])))];
		yptr2[23]=tpalette[(pgm_read_byte(&(yptr[23])))];
		yptr2[24]=tpalette[(pgm_read_byte(&(yptr[24])))];
		yptr2[25]=tpalette[(pgm_read_byte(&(yptr[25])))];
		yptr2[26]=tpalette[(pgm_read_byte(&(yptr[26])))];
		yptr2[27]=tpalette[(pgm_read_byte(&(yptr[27])))];
		yptr2[28]=tpalette[(pgm_read_byte(&(yptr[28])))];
		yptr2[29]=tpalette[(pgm_read_byte(&(yptr[29])))];
		yptr2[30]=tpalette[(pgm_read_byte(&(yptr[30])))];
		yptr2[31]=tpalette[(pgm_read_byte(&(yptr[31])))];
	}

}



void incrementProgram(){

	curImage++;
	if(curImage>15){curImage=0;}
	loadPalette(curImage);
}


int main(void)
{

	TCCR1B |= (1 << WGM12); // SET TIMER 1 TO CTC MODE (OCR1A)
	TIMSK1 |= (1 << OCIE1A);// ENABLE INTERRUPT AT COMPARE MATCH WITH OCR1A
	OCR1A = 911; 		  	// HORIZONTAL DRIVE TIME   
	TCCR1B |= (1 << CS10);  // ENABLE CLOCK & SET PRESCALER OFF

	DDRB = 0xFF;			// ENABLE WRITE TO PORTB ALL PINS
	DDRD = 0xEF;			// ENABLE WRITE TO PD0,PD1,PD2,PD3,PD5,PD6,PD7, READ FROM PD4 (freq counter)
	DDRC = 0x00;			// ENABLE READ TO PORTC (all pins)

    OCR2A  = 0x01;			// COLOR SUBCARRIER SETUP
	TCCR2A = 0x42;
	TCCR2B = 0x09;

	DIDR0 = 0x07;			// DISABLE DIGITAL OUT ON ADC CHANNELS

	ADCSRA|=(1<<ADPS1);
	ADC_SELECT_ENVFOLLOWER;	
	ADC_START;

	TCCR0B |= (1 << CS01);	// ENABLE FREQ COUNTER
	TCCR0B |= (1 << CS02);

	loadPalette(curPalette);
	loadFrameBuffer(curImage);
	sei();

    for(;;){

		if(displayline && (line==(ENDLINE+1))){

			if(field){ 
				field=0;
				loadFrameBuffer(curImage);	
				peakDetect=0;
			} 
			
			if(!field) { 
				field=1;
				ADC_SELECT_PARAM1;
				ADC_START;
				LED1_OFF;
				LED2_OFF;

				peakDetect=0;
				for(i=0;i<32;i++){
					if(envFollower[i]>=34){peakDetect++;}
				}

				if(peakDetect>=30 && pkDelayCnt >= PEAK_DELAY){ 
					pkDelayCnt=0; 
					LED1_ON; 
					switch(curActionMode){
						case 0: break; //donothing
						case 1: incrementXMode();  break;
						case 2: incrementYMode();  break;
						case 3: incrementXMode(); incrementYMode(); break;
					}
				} 

				pkDelayCnt++; 

				frmCnt1++; if(frmCnt1>=frmCnt1Speed){frmCnt1=0;  LED2_ON;	
				
				switch(curCntMode){

					case 0: shiftPalette(1); break;
					case 1: allPalette(0); break;
					case 2: allPalette(1); break;
					case 3: allPalette(2); break;
					case 4: allPalette(3); break;
					case 5: allPalette(4); break;
					case 6: allPalette(5); break;
					case 7: randomPalette(0); break;
					case 8: randomPalette(1); break;
					case 9: randomPalette(2); break;
					case 10: randomPalette(3); break;
					case 11: randomPalette(4); break;
					case 12: randomPalette(5); break;
				
					}
				}

				frmCnt1Speed=(ADCH>>2); 

				ADC_SELECT_PARAM2;
				ADC_START;

				int b; 
				int p;
				int m=0;
				
				p=b=(PINC&8)>>3; //PROGRAM
				if(b) { btoggle[0]=0; }
				else if (!b && !btoggle[0]) { if(!((PINC&32)>>5)) {incrementCntAction(); } else { btoggle[0]=1; incrementProgram(); }}						
				b=(PINC&16)>>4; //ACTION 						
				if(b) { btoggle[1]=0; }
				else if (!b && !btoggle[1]){ if(!((PINC&32)>>5)) {incrementXMode(); incrementYMode();} else { incrementAction(); }btoggle[1]=1; }	
				b=(PINC&32)>>5; //MODE
				if(b) { btoggle[2]=0; }			
				else if (!b && !btoggle[2]){ if(!p){ m=1; incrementPalette(); } else { incrementLineMode();  }btoggle[2]=1; }		
						
				frqCnt=TCNT0;
				TCNT0=0;
				
				if(frqCnt>192){ 		frqRange=15; } 
				else if(frqCnt>128) { 	frqRange=14; } // 7680Hz
				else if(frqCnt>96) { 	frqRange=13; } 
				else if(frqCnt>64) { 	frqRange=12; } // 3840Hz
				else if(frqCnt>48) { 	frqRange=11; } 
				else if(frqCnt>32) { 	frqRange=10; } // 1920Hz
				else if(frqCnt>24) { 	frqRange=9; } 
				else if(frqCnt>16) { 	frqRange=8; } // 960Hz
				else if(frqCnt>12) { 	frqRange=7; } 
				else if(frqCnt>8) { 	frqRange=6; } // 480Hz
				else if(frqCnt>6) { 	frqRange=5; } 
				else if(frqCnt>4) { 	frqRange=4; } // 240Hz
				else if(frqCnt>3) { 	frqRange=3; } 
				else if(frqCnt>2) { 	frqRange=2; } // 120Hz
				else if(frqCnt>1) { 	frqRange=1; } 
				else { 					frqRange=0; } // <30Hz 
				envOffset=(ADCH>>3);
			}
			ADC_SELECT_ENVFOLLOWER;	
			ADC_START;
			displayline=0;			
		}

		if(displayline && (line>=STARTLINE) && (line<=ENDLINE)){
			
			switch(xmode){
			case 2: 
				PORTD = yptr[0];BLACK_OFF;PORTD = yptr[0];PORTD = yptr[0];PORTD = yptr[0];
				PORTD = yptr[1];PORTD = yptr[1];PORTD = yptr[1];PORTD = yptr[1];PORTD = yptr[1];PORTD = yptr[1];
				PORTD = yptr[2];PORTD = yptr[2];PORTD = yptr[2];PORTD = yptr[2];PORTD = yptr[2];PORTD = yptr[2];
				PORTD = yptr[3];PORTD = yptr[3];PORTD = yptr[3];PORTD = yptr[3];PORTD = yptr[3];PORTD = yptr[3];
				PORTD = yptr[4];PORTD = yptr[4];PORTD = yptr[4];PORTD = yptr[4];PORTD = yptr[4];PORTD = yptr[4];
				PORTD = yptr[5];PORTD = yptr[5];PORTD = yptr[5];PORTD = yptr[5];PORTD = yptr[5];PORTD = yptr[5];
				PORTD = yptr[6];PORTD = yptr[6];PORTD = yptr[6];PORTD = yptr[6];PORTD = yptr[6];PORTD = yptr[6];
				PORTD = yptr[7];PORTD = yptr[7];PORTD = yptr[7];PORTD = yptr[7];PORTD = yptr[7];PORTD = yptr[7];
				PORTD = yptr[8];PORTD = yptr[8];PORTD = yptr[8];PORTD = yptr[8];PORTD = yptr[8];PORTD = yptr[8];
				PORTD = yptr[9];PORTD = yptr[9];PORTD = yptr[9];PORTD = yptr[9];PORTD = yptr[9];PORTD = yptr[9];
				PORTD = yptr[10];PORTD = yptr[10];PORTD = yptr[10];PORTD = yptr[10];PORTD = yptr[10];PORTD = yptr[10];
				PORTD = yptr[11];PORTD = yptr[11];PORTD = yptr[11];PORTD = yptr[11];PORTD = yptr[11];PORTD = yptr[11];
				PORTD = yptr[12];PORTD = yptr[12];PORTD = yptr[12];PORTD = yptr[12];PORTD = yptr[12];PORTD = yptr[12];
				PORTD = yptr[13];PORTD = yptr[13];PORTD = yptr[13];PORTD = yptr[13];PORTD = yptr[13];PORTD = yptr[13];
				PORTD = yptr[14];PORTD = yptr[14];PORTD = yptr[14];PORTD = yptr[14];PORTD = yptr[14];PORTD = yptr[14];
				PORTD = yptr[15];PORTD = yptr[15];PORTD = yptr[15];PORTD = yptr[15];PORTD = yptr[15];PORTD = yptr[15];
				PORTD = yptr[16];PORTD = yptr[16];PORTD = yptr[16];PORTD = yptr[16];PORTD = yptr[16];PORTD = yptr[16];
				PORTD = yptr[17];PORTD = yptr[17];PORTD = yptr[17];PORTD = yptr[17];PORTD = yptr[17];PORTD = yptr[17];
				PORTD = yptr[18];PORTD = yptr[18];PORTD = yptr[18];PORTD = yptr[18];PORTD = yptr[18];PORTD = yptr[18];
				PORTD = yptr[19];PORTD = yptr[19];PORTD = yptr[19];PORTD = yptr[19];PORTD = yptr[19];PORTD = yptr[19];
				PORTD = yptr[20];PORTD = yptr[20];PORTD = yptr[20];PORTD = yptr[20];PORTD = yptr[20];PORTD = yptr[20];
				PORTD = yptr[21];PORTD = yptr[21];PORTD = yptr[21];PORTD = yptr[21];PORTD = yptr[21];PORTD = yptr[21];
				PORTD = yptr[22];PORTD = yptr[22];PORTD = yptr[22];PORTD = yptr[22];PORTD = yptr[22];PORTD = yptr[22];
				PORTD = yptr[23];PORTD = yptr[23];PORTD = yptr[23];PORTD = yptr[23];PORTD = yptr[23];PORTD = yptr[23];
				PORTD = yptr[24];PORTD = yptr[24];PORTD = yptr[24];PORTD = yptr[24];PORTD = yptr[24];PORTD = yptr[24];
				PORTD = yptr[25];PORTD = yptr[25];PORTD = yptr[25];PORTD = yptr[25];PORTD = yptr[25];PORTD = yptr[25];
				PORTD = yptr[26];PORTD = yptr[26];PORTD = yptr[26];PORTD = yptr[26];PORTD = yptr[26];PORTD = yptr[26];
				PORTD = yptr[27];PORTD = yptr[27];PORTD = yptr[27];PORTD = yptr[27];PORTD = yptr[27];PORTD = yptr[27];
				PORTD = yptr[28];PORTD = yptr[28];PORTD = yptr[28];PORTD = yptr[28];PORTD = yptr[28];PORTD = yptr[28];
				PORTD = yptr[29];PORTD = yptr[29];PORTD = yptr[29];PORTD = yptr[29];PORTD = yptr[29];PORTD = yptr[29];
				PORTD = yptr[30];PORTD = yptr[30];//PORTD = yptr[30];PORTD = yptr[30];PORTD = yptr[30];PORTD = yptr[30];
				//PORTD = yptr[31];PORTD = yptr[31];PORTD = yptr[31];PORTD = yptr[31];PORTD = yptr[31];PORTD = yptr[31];


				break;
			case 1: 
				PORTD = yptr[0];BLACK_OFF;PORTD = yptr[0];
				PORTD = yptr[1];PORTD = yptr[1];
				PORTD = yptr[2];PORTD = yptr[2];
				PORTD = yptr[3];PORTD = yptr[3];
				PORTD = yptr[4];PORTD = yptr[4];
				PORTD = yptr[5];PORTD = yptr[5];
				PORTD = yptr[6];PORTD = yptr[6];
				PORTD = yptr[7];PORTD = yptr[7];
				PORTD = yptr[8];PORTD = yptr[8];
				PORTD = yptr[9];PORTD = yptr[9];
				PORTD = yptr[10];PORTD = yptr[10];
				PORTD = yptr[11];PORTD = yptr[11];
				PORTD = yptr[12];PORTD = yptr[12];
				PORTD = yptr[13];PORTD = yptr[13];
				PORTD = yptr[14];PORTD = yptr[14];
				PORTD = yptr[15];PORTD = yptr[15];
				PORTD = yptr[16];PORTD = yptr[16];
				PORTD = yptr[17];PORTD = yptr[17];
				PORTD = yptr[18];PORTD = yptr[18];
				PORTD = yptr[19];PORTD = yptr[19];
				PORTD = yptr[20];PORTD = yptr[20];
				PORTD = yptr[21];PORTD = yptr[21];
				PORTD = yptr[22];PORTD = yptr[22];
				PORTD = yptr[23];PORTD = yptr[23];
				PORTD = yptr[24];PORTD = yptr[24];
				PORTD = yptr[25];PORTD = yptr[25];
				PORTD = yptr[26];PORTD = yptr[26];
				PORTD = yptr[27];PORTD = yptr[27];
				PORTD = yptr[28];PORTD = yptr[28];
				PORTD = yptr[29];PORTD = yptr[29];
				PORTD = yptr[30];PORTD = yptr[30];
				PORTD = yptr[31];PORTD = yptr[31];
				PORTD = yptr[0];PORTD = yptr[0];
				PORTD = yptr[1];PORTD = yptr[1];
				PORTD = yptr[2];PORTD = yptr[2];
				PORTD = yptr[3];PORTD = yptr[3];
				PORTD = yptr[4];PORTD = yptr[4];
				PORTD = yptr[5];PORTD = yptr[5];
				PORTD = yptr[6];PORTD = yptr[6];
				PORTD = yptr[7];PORTD = yptr[7];
				PORTD = yptr[8];PORTD = yptr[8];
				PORTD = yptr[9];PORTD = yptr[9];
				PORTD = yptr[10];PORTD = yptr[10];
				PORTD = yptr[11];PORTD = yptr[11];
				PORTD = yptr[12];PORTD = yptr[12];
				PORTD = yptr[13];PORTD = yptr[13];
				PORTD = yptr[14];PORTD = yptr[14];
				PORTD = yptr[15];PORTD = yptr[15];
				PORTD = yptr[16];PORTD = yptr[16];
				PORTD = yptr[17];PORTD = yptr[17];
				PORTD = yptr[18];PORTD = yptr[18];
				PORTD = yptr[19];PORTD = yptr[19];
				PORTD = yptr[20];PORTD = yptr[20];
				PORTD = yptr[21];PORTD = yptr[21];
				PORTD = yptr[22];PORTD = yptr[22];
				PORTD = yptr[23];PORTD = yptr[23];
				PORTD = yptr[24];PORTD = yptr[24];
				PORTD = yptr[25];PORTD = yptr[25];
				PORTD = yptr[26];PORTD = yptr[26];
				PORTD = yptr[27];PORTD = yptr[27];
				PORTD = yptr[28];PORTD = yptr[28];
				PORTD = yptr[29];PORTD = yptr[29];
				PORTD = yptr[30];PORTD = yptr[30];
				PORTD = yptr[31];PORTD = yptr[31];
				PORTD = yptr[0];PORTD = yptr[0];
				PORTD = yptr[1];PORTD = yptr[1];
				PORTD = yptr[2];PORTD = yptr[2];
				PORTD = yptr[3];PORTD = yptr[3];
				PORTD = yptr[4];PORTD = yptr[4];
				PORTD = yptr[5];PORTD = yptr[5];
				PORTD = yptr[6];PORTD = yptr[6];
				PORTD = yptr[7];PORTD = yptr[7];
				PORTD = yptr[8];PORTD = yptr[8];
				PORTD = yptr[9];PORTD = yptr[9];
				PORTD = yptr[10];PORTD = yptr[10];
				PORTD = yptr[11];PORTD = yptr[11];
				PORTD = yptr[12];PORTD = yptr[12];
				PORTD = yptr[13];PORTD = yptr[13];
				PORTD = yptr[14];PORTD = yptr[14];
				PORTD = yptr[15];PORTD = yptr[15];
				PORTD = yptr[16];PORTD = yptr[16];
				PORTD = yptr[17];PORTD = yptr[17];
				PORTD = yptr[18];PORTD = yptr[18];
				PORTD = yptr[19];PORTD = yptr[19];
				PORTD = yptr[20];PORTD = yptr[20];
				PORTD = yptr[21];PORTD = yptr[21];
				PORTD = yptr[22];PORTD = yptr[22];
				PORTD = yptr[23];PORTD = yptr[23];
				PORTD = yptr[24];PORTD = yptr[24];
				PORTD = yptr[25];PORTD = yptr[25];
				PORTD = yptr[26];PORTD = yptr[26];
				//PORTD = yptr[27];PORTD = yptr[27];
				//PORTD = yptr[28];PORTD = yptr[28];
				//PORTD = yptr[29];PORTD = yptr[29];
				//PORTD = yptr[30];PORTD = yptr[30];
				//PORTD = yptr[31];PORTD = yptr[31];

			break;
			case 0:
				PORTD = yptr[0];BLACK_OFF;
				PORTD = yptr[1];
				PORTD = yptr[2];
				PORTD = yptr[3];
				PORTD = yptr[4];
				PORTD = yptr[5];
				PORTD = yptr[6];
				PORTD = yptr[7];
				PORTD = yptr[8];
				PORTD = yptr[9];
				PORTD = yptr[10];
				PORTD = yptr[11];
				PORTD = yptr[12];
				PORTD = yptr[13];
				PORTD = yptr[14];
				PORTD = yptr[15];
				PORTD = yptr[16];
				PORTD = yptr[17];
				PORTD = yptr[18];
				PORTD = yptr[19];
				PORTD = yptr[20];
				PORTD = yptr[21];
				PORTD = yptr[22];
				PORTD = yptr[23];
				PORTD = yptr[24];
				PORTD = yptr[25];
				PORTD = yptr[26];
				PORTD = yptr[27];
				PORTD = yptr[28];
				PORTD = yptr[29];
				PORTD = yptr[30];
				PORTD = yptr[31];

				PORTD = yptr[0];
				PORTD = yptr[1];
				PORTD = yptr[2];
				PORTD = yptr[3];
				PORTD = yptr[4];
				PORTD = yptr[5];
				PORTD = yptr[6];
				PORTD = yptr[7];
				PORTD = yptr[8];
				PORTD = yptr[9];
				PORTD = yptr[10];
				PORTD = yptr[11];
				PORTD = yptr[12];
				PORTD = yptr[13];
				PORTD = yptr[14];
				PORTD = yptr[15];
				PORTD = yptr[16];
				PORTD = yptr[17];
				PORTD = yptr[18];
				PORTD = yptr[19];
				PORTD = yptr[20];
				PORTD = yptr[21];
				PORTD = yptr[22];
				PORTD = yptr[23];
				PORTD = yptr[24];
				PORTD = yptr[25];
				PORTD = yptr[26];
				PORTD = yptr[27];
				PORTD = yptr[28];
				PORTD = yptr[29];
				PORTD = yptr[30];
				PORTD = yptr[31];

				PORTD = yptr[0];
				PORTD = yptr[1];
				PORTD = yptr[2];
				PORTD = yptr[3];
				PORTD = yptr[4];
				PORTD = yptr[5];
				PORTD = yptr[6];
				PORTD = yptr[7];
				PORTD = yptr[8];
				PORTD = yptr[9];
				PORTD = yptr[10];
				PORTD = yptr[11];
				PORTD = yptr[12];
				PORTD = yptr[13];
				PORTD = yptr[14];
				PORTD = yptr[15];
				PORTD = yptr[16];
				PORTD = yptr[17];
				PORTD = yptr[18];
				PORTD = yptr[19];
				PORTD = yptr[20];
				PORTD = yptr[21];
				PORTD = yptr[22];
				PORTD = yptr[23];
				PORTD = yptr[24];
				PORTD = yptr[25];
				PORTD = yptr[26];
				PORTD = yptr[27];
				PORTD = yptr[28];
				PORTD = yptr[29];
				PORTD = yptr[30];
				PORTD = yptr[31];

				PORTD = yptr[0];
				PORTD = yptr[1];
				PORTD = yptr[2];
				PORTD = yptr[3];
				PORTD = yptr[4];
				PORTD = yptr[5];
				PORTD = yptr[6];
				PORTD = yptr[7];
				PORTD = yptr[8];
				PORTD = yptr[9];
				PORTD = yptr[10];
				PORTD = yptr[11];
				PORTD = yptr[12];
				PORTD = yptr[13];
				PORTD = yptr[14];
				PORTD = yptr[15];
				PORTD = yptr[16];
				PORTD = yptr[17];
				PORTD = yptr[18];
				PORTD = yptr[19];
				PORTD = yptr[20];
				PORTD = yptr[21];
				PORTD = yptr[22];
				PORTD = yptr[23];
				PORTD = yptr[24];
				PORTD = yptr[25];
				PORTD = yptr[26];
				PORTD = yptr[27];
				PORTD = yptr[28];
				PORTD = yptr[29];
				PORTD = yptr[30];
				PORTD = yptr[31];
				PORTD = yptr[0];
				PORTD = yptr[1];
				PORTD = yptr[2];
				PORTD = yptr[3];
				PORTD = yptr[4];
				PORTD = yptr[5];
				PORTD = yptr[6];
				PORTD = yptr[7];
				PORTD = yptr[8];
				PORTD = yptr[9];
				PORTD = yptr[10];
				PORTD = yptr[11];
				PORTD = yptr[12];
				PORTD = yptr[13];
				PORTD = yptr[14];
				PORTD = yptr[15];
				PORTD = yptr[16];
				PORTD = yptr[17];
				PORTD = yptr[18];
				PORTD = yptr[19];
				PORTD = yptr[20];
				PORTD = yptr[21];
				PORTD = yptr[22];
				PORTD = yptr[23];
				PORTD = yptr[24];
				PORTD = yptr[25];
				PORTD = yptr[26];
				PORTD = yptr[27];
				PORTD = yptr[28];
				PORTD = yptr[29];
				PORTD = yptr[30];
				PORTD = yptr[31];

				PORTD = yptr[0];
				PORTD = yptr[1];
				PORTD = yptr[2];
				PORTD = yptr[3];
				PORTD = yptr[4];
				PORTD = yptr[5];
				PORTD = yptr[6];
				PORTD = yptr[7];
				PORTD = yptr[8];
				PORTD = yptr[9];
				PORTD = yptr[10];
				PORTD = yptr[11];
				PORTD = yptr[12];
				PORTD = yptr[13];
				PORTD = yptr[14];
				PORTD = yptr[15];
				PORTD = yptr[16];
				PORTD = yptr[17];
				PORTD = yptr[18];
				PORTD = yptr[19];
				PORTD = yptr[20];
				PORTD = yptr[21];
				//PORTD = yptr[22];
				//PORTD = yptr[23];
				//PORTD = yptr[24];
				//PORTD = yptr[25];
				//PORTD = yptr[26];
				//PORTD = yptr[27];
				//PORTD = yptr[28];
				//PORTD = yptr[29];
				//PORTD = yptr[30];
				//PORTD = yptr[31];
				break;
			case 3:
				PORTD = yptr[0];BLACK_OFF;
				PORTD = yptr[1];
				PORTD = yptr[2];
				PORTD = yptr[3];
				PORTD = yptr[4];
				PORTD = yptr[5];
				PORTD = yptr[6];
				PORTD = yptr[7];
				PORTD = yptr[8];
				PORTD = yptr[9];
				PORTD = yptr[10];
				PORTD = yptr[11];
				PORTD = yptr[12];
				PORTD = yptr[13];
				PORTD = yptr[14];
				PORTD = yptr[15];
				PORTD = yptr[16];
				PORTD = yptr[17];
				PORTD = yptr[18];
				PORTD = yptr[19];
				PORTD = yptr[20];
				PORTD = yptr[21];
				PORTD = yptr[22];
				PORTD = yptr[23];
				PORTD = yptr[24];
				PORTD = yptr[25];
				PORTD = yptr[26];
				PORTD = yptr[27];
				PORTD = yptr[28];
				PORTD = yptr[29];
				PORTD = yptr[30];
				PORTD = yptr[31];

				PORTD = yptr[31];
				PORTD = yptr[30];
				PORTD = yptr[29];
				PORTD = yptr[28];
				PORTD = yptr[27];
				PORTD = yptr[26];
				PORTD = yptr[25];
				PORTD = yptr[24];
				PORTD = yptr[23];
				PORTD = yptr[22];
				PORTD = yptr[21];
				PORTD = yptr[20];
				PORTD = yptr[19];
				PORTD = yptr[18];
				PORTD = yptr[17];
				PORTD = yptr[16];
				PORTD = yptr[15];
				PORTD = yptr[14];
				PORTD = yptr[13];
				PORTD = yptr[12];
				PORTD = yptr[11];
				PORTD = yptr[10];
				PORTD = yptr[9];
				PORTD = yptr[8];
				PORTD = yptr[7];
				PORTD = yptr[6];
				PORTD = yptr[5];
				PORTD = yptr[4];
				PORTD = yptr[3];
				PORTD = yptr[2];
				PORTD = yptr[1];
				PORTD = yptr[0];

				PORTD = yptr[0];
				PORTD = yptr[1];
				PORTD = yptr[2];
				PORTD = yptr[3];
				PORTD = yptr[4];
				PORTD = yptr[5];
				PORTD = yptr[6];
				PORTD = yptr[7];
				PORTD = yptr[8];
				PORTD = yptr[9];
				PORTD = yptr[10];
				PORTD = yptr[11];
				PORTD = yptr[12];
				PORTD = yptr[13];
				PORTD = yptr[14];
				PORTD = yptr[15];
				PORTD = yptr[16];
				PORTD = yptr[17];
				PORTD = yptr[18];
				PORTD = yptr[19];
				PORTD = yptr[20];
				PORTD = yptr[21];
				PORTD = yptr[22];
				PORTD = yptr[23];
				PORTD = yptr[24];
				PORTD = yptr[25];
				PORTD = yptr[26];
				PORTD = yptr[27];
				PORTD = yptr[28];
				PORTD = yptr[29];
				PORTD = yptr[30];
				PORTD = yptr[31];

				PORTD = yptr[31];
				PORTD = yptr[30];
				PORTD = yptr[29];
				PORTD = yptr[28];
				PORTD = yptr[27];
				PORTD = yptr[26];
				PORTD = yptr[25];
				PORTD = yptr[24];
				PORTD = yptr[23];
				PORTD = yptr[22];
				PORTD = yptr[21];
				PORTD = yptr[20];
				PORTD = yptr[19];
				PORTD = yptr[18];
				PORTD = yptr[17];
				PORTD = yptr[16];
				PORTD = yptr[15];
				PORTD = yptr[14];
				PORTD = yptr[13];
				PORTD = yptr[12];
				PORTD = yptr[11];
				PORTD = yptr[10];
				PORTD = yptr[9];
				PORTD = yptr[8];
				PORTD = yptr[7];
				PORTD = yptr[6];
				PORTD = yptr[5];
				PORTD = yptr[4];
				PORTD = yptr[3];
				PORTD = yptr[2];
				PORTD = yptr[1];
				PORTD = yptr[0];

				PORTD = yptr[0];
				PORTD = yptr[1];
				PORTD = yptr[2];
				PORTD = yptr[3];
				PORTD = yptr[4];
				PORTD = yptr[5];
				PORTD = yptr[6];
				PORTD = yptr[7];
				PORTD = yptr[8];
				PORTD = yptr[9];
				PORTD = yptr[10];
				PORTD = yptr[11];
				PORTD = yptr[12];
				PORTD = yptr[13];
				PORTD = yptr[14];
				PORTD = yptr[15];
				PORTD = yptr[16];
				PORTD = yptr[17];
				PORTD = yptr[18];
				PORTD = yptr[19];
				PORTD = yptr[20];
				PORTD = yptr[21];
				PORTD = yptr[22];
				PORTD = yptr[23];
				PORTD = yptr[24];
				PORTD = yptr[25];
				PORTD = yptr[26];
				PORTD = yptr[27];
				PORTD = yptr[28];
				PORTD = yptr[29];
				PORTD = yptr[30];
				PORTD = yptr[31];

				PORTD = yptr[31];
				PORTD = yptr[30];
				PORTD = yptr[29];
				PORTD = yptr[28];
				PORTD = yptr[27];
				PORTD = yptr[26];
				PORTD = yptr[25];
				PORTD = yptr[24];
				PORTD = yptr[23];
				PORTD = yptr[22];
				PORTD = yptr[21];
				PORTD = yptr[20];
				PORTD = yptr[19];
				PORTD = yptr[18];
				PORTD = yptr[17];
				PORTD = yptr[16];
				PORTD = yptr[15];
				PORTD = yptr[14];
				PORTD = yptr[13];
				PORTD = yptr[12];
				PORTD = yptr[11];
				PORTD = yptr[10];
				//PORTD = yptr[9];
				//PORTD = yptr[8];
				//PORTD = yptr[7];
				//PORTD = yptr[6];
				//PORTD = yptr[5];
				//PORTD = yptr[4];
				//PORTD = yptr[3];
				//PORTD = yptr[2];
				//PORTD = yptr[1];
				//PORTD = yptr[0];
				break;
			}
			BLACK_ON;				  // BLACK
			yptr=fbuffer[(((line - STARTLINE) >> ymode) & (FBUFFER_HEIGHT-1))];
			envFollower[(((line - STARTLINE) >> 2) & (FBUFFER_HEIGHT-1))]=ADCH;
			displayline=0;
		}
		sleep_mode();		
	} 
} 



